# This File GEN using nerdicons_gen.py

class Fa:

	# CHAR : 
	fa_500px = "\uf26e"
	# CHAR : 
	fa_accessible_icon = "\uf29b"
	# CHAR : 
	fa_accusoft = "\uf0b7"
	# CHAR : 
	fa_address_book = "\uf2b9"
	# CHAR : 
	fa_address_book_o = "\uf2ba"
	# CHAR : 
	fa_address_card = "\uf2bb"
	# CHAR : 
	fa_address_card_o = "\uf2bc"
	# CHAR : 
	fa_adjust = "\uf042"
	# CHAR : 
	fa_adn = "\uf170"
	# CHAR : 
	fa_adversal = "\uf0b8"
	# CHAR : 
	fa_affiliatetheme = "\uf0b9"
	# CHAR : 
	fa_airbnb = "\uef93"
	# CHAR : 
	fa_algolia = "\uf0ba"
	# CHAR : 
	fa_align_center = "\uf037"
	# CHAR : 
	fa_align_justify = "\uf039"
	# CHAR : 
	fa_align_left = "\uf036"
	# CHAR : 
	fa_align_right = "\uf038"
	# CHAR : 
	fa_alipay = "\ueebc"
	# CHAR : 
	fa_amazon = "\uf270"
	# CHAR : 
	fa_amazon_pay = "\ued56"
	# CHAR : 
	fa_ambulance = "\uf0f9"
	# CHAR : 
	fa_american_sign_language_interpreting = "\uf2a3"
	# CHAR : 
	fa_amilia = "\uf0bb"
	# CHAR : 
	fa_anchor = "\uf13d"
	# CHAR : 
	fa_android = "\uf17b"
	# CHAR : 
	fa_angellist = "\uf209"
	# CHAR : 
	fa_angle_double_down = "\uf103"
	# CHAR : 
	fa_angle_double_left = "\uf100"
	# CHAR : 
	fa_angle_double_right = "\uf101"
	# CHAR : 
	fa_angle_double_up = "\uf102"
	# CHAR : 
	fa_angle_down = "\uf107"
	# CHAR : 
	fa_angle_left = "\uf104"
	# CHAR : 
	fa_angle_right = "\uf105"
	# CHAR : 
	fa_angle_up = "\uf106"
	# CHAR : 
	fa_angles_down = "\uf103"
	# CHAR : 
	fa_angles_left = "\uf100"
	# CHAR : 
	fa_angles_right = "\uf101"
	# CHAR : 
	fa_angles_up = "\uf102"
	# CHAR : 
	fa_angrycreative = "\uf0bc"
	# CHAR : 
	fa_angular = "\ued4b"
	# CHAR : 
	fa_ankh = "\ueebd"
	# CHAR : 
	fa_app_store = "\uf0bd"
	# CHAR : 
	fa_app_store_ios = "\uf0be"
	# CHAR : 
	fa_apper = "\uf0bf"
	# CHAR : 
	fa_apple = "\uf179"
	# CHAR : 
	fa_apple_pay = "\ued41"
	# CHAR : 
	fa_apple_whole = "\uee98"
	# CHAR : 
	fa_archive = "\uf187"
	# CHAR : 
	fa_archway = "\uee20"
	# CHAR : 
	fa_area_chart = "\uf1fe"
	# CHAR : 
	fa_arrow_circle_down = "\uf0ab"
	# CHAR : 
	fa_arrow_circle_left = "\uf0a8"
	# CHAR : 
	fa_arrow_circle_o_down = "\uf01a"
	# CHAR : 
	fa_arrow_circle_o_left = "\uf190"
	# CHAR : 
	fa_arrow_circle_o_right = "\uf18e"
	# CHAR : 
	fa_arrow_circle_o_up = "\uf01b"
	# CHAR : 
	fa_arrow_circle_right = "\uf0a9"
	# CHAR : 
	fa_arrow_circle_up = "\uf0aa"
	# CHAR : 
	fa_arrow_down = "\uf063"
	# CHAR : 
	fa_arrow_down_1_9 = "\uf162"
	# CHAR : 
	fa_arrow_down_9_1 = "\uefb1"
	# CHAR : 
	fa_arrow_down_a_z = "\uf15d"
	# CHAR : 
	fa_arrow_down_long = "\uf175"
	# CHAR : 
	fa_arrow_down_short_wide = "\uefaf"
	# CHAR : 
	fa_arrow_down_wide_short = "\uf160"
	# CHAR : 
	fa_arrow_down_z_a = "\uefad"
	# CHAR : 
	fa_arrow_left = "\uf060"
	# CHAR : 
	fa_arrow_left_long = "\uf177"
	# CHAR : 
	fa_arrow_pointer = "\uf245"
	# CHAR : 
	fa_arrow_right = "\uf061"
	# CHAR : 
	fa_arrow_right_arrow_left = "\uf0ec"
	# CHAR : 
	fa_arrow_right_from_bracket = "\uf08b"
	# CHAR : 
	fa_arrow_right_long = "\uf178"
	# CHAR : 
	fa_arrow_right_to_bracket = "\uf090"
	# CHAR : 
	fa_arrow_rotate_left = "\uf0e2"
	# CHAR : 
	fa_arrow_rotate_right = "\uf01e"
	# CHAR : 
	fa_arrow_turn_down = "\uf149"
	# CHAR : 
	fa_arrow_turn_up = "\uf148"
	# CHAR : 
	fa_arrow_up = "\uf062"
	# CHAR : 
	fa_arrow_up_1_9 = "\uf163"
	# CHAR : 
	fa_arrow_up_9_1 = "\uefb2"
	# CHAR : 
	fa_arrow_up_a_z = "\uf15e"
	# CHAR : 
	fa_arrow_up_long = "\uf176"
	# CHAR : 
	fa_arrow_up_right_from_square = "\uf08e"
	# CHAR : 
	fa_arrow_up_short_wide = "\uefb0"
	# CHAR : 
	fa_arrow_up_wide_short = "\uf161"
	# CHAR : 
	fa_arrow_up_z_a = "\uefae"
	# CHAR : 
	fa_arrows = "\uf047"
	# CHAR : 
	fa_arrows_alt = "\uf0b2"
	# CHAR : 
	fa_arrows_h = "\uf07e"
	# CHAR : 
	fa_arrows_left_right = "\uf07e"
	# CHAR : 
	fa_arrows_rotate = "\uf021"
	# CHAR : 
	fa_arrows_up_down = "\uf07d"
	# CHAR : 
	fa_arrows_up_down_left_right = "\uf047"
	# CHAR : 
	fa_arrows_v = "\uf07d"
	# CHAR : 
	fa_artstation = "\uef31"
	# CHAR : 
	fa_asl_interpreting = "\uf2a3"
	# CHAR : 
	fa_assistive_listening_systems = "\uf2a2"
	# CHAR : 
	fa_asterisk = "\uf069"
	# CHAR : 
	fa_asymmetrik = "\uf0cf"
	# CHAR : 
	fa_at = "\uf1fa"
	# CHAR : 
	fa_atlassian = "\uef32"
	# CHAR : 
	fa_atom = "\uee99"
	# CHAR : 
	fa_audible = "\uf0df"
	# CHAR : 
	fa_audio_description = "\uf29e"
	# CHAR : 
	fa_automobile = "\uf1b9"
	# CHAR : 
	fa_autoprefixer = "\ued47"
	# CHAR : 
	fa_avianex = "\uefc2"
	# CHAR : 
	fa_aviato = "\ued4c"
	# CHAR : 
	fa_award = "\uee22"
	# CHAR : 
	fa_aws = "\uf0ef"
	# CHAR : 
	fa_baby = "\uef33"
	# CHAR : 
	fa_baby_carriage = "\uef34"
	# CHAR : 
	fa_backward = "\uf04a"
	# CHAR : 
	fa_backward_fast = "\uf049"
	# CHAR : 
	fa_backward_step = "\uf048"
	# CHAR : 
	fa_bacon = "\uef77"
	# CHAR : 
	fa_bag_shopping = "\uf290"
	# CHAR : 
	fa_bahai = "\ueecb"
	# CHAR : 
	fa_balance_scale = "\uf24e"
	# CHAR : 
	fa_ban = "\uf05e"
	# CHAR : 
	fa_ban_smoking = "\uee16"
	# CHAR : 
	fa_bandage = "\ued74"
	# CHAR : 
	fa_bandcamp = "\uf2d5"
	# CHAR : 
	fa_bank = "\uf19c"
	# CHAR : 
	fa_bar_chart = "\uf080"
	# CHAR : 
	fa_bar_chart_o = "\uf080"
	# CHAR : 
	fa_barcode = "\uf02a"
	# CHAR : 
	fa_bars = "\uf0c9"
	# CHAR : 
	fa_bars_progress = "\uef8f"
	# CHAR : 
	fa_bars_staggered = "\uee19"
	# CHAR : 
	fa_baseball = "\ued5c"
	# CHAR : 
	fa_baseball_bat_ball = "\ued5b"
	# CHAR : 
	fa_basket_shopping = "\uf291"
	# CHAR : 
	fa_basketball = "\ued5d"
	# CHAR : 
	fa_bath = "\uf2cd"
	# CHAR : 
	fa_bathtub = "\uf2cd"
	# CHAR : 
	fa_battery = "\uf240"
	# CHAR : 
	fa_battery_0 = "\uf244"
	# CHAR : 
	fa_battery_1 = "\uf243"
	# CHAR : 
	fa_battery_2 = "\uf242"
	# CHAR : 
	fa_battery_3 = "\uf241"
	# CHAR : 
	fa_battery_4 = "\uf240"
	# CHAR : 
	fa_battery_empty = "\uf244"
	# CHAR : 
	fa_battery_full = "\uf240"
	# CHAR : 
	fa_battery_half = "\uf242"
	# CHAR : 
	fa_battery_quarter = "\uf243"
	# CHAR : 
	fa_battery_three_quarters = "\uf241"
	# CHAR : 
	fa_battle_net = "\uef94"
	# CHAR : 
	fa_bed = "\uf236"
	# CHAR : 
	fa_bed_pulse = "\ued8a"
	# CHAR : 
	fa_beer = "\uf0fc"
	# CHAR : 
	fa_beer_mug_empty = "\uf0fc"
	# CHAR : 
	fa_behance = "\uf1b4"
	# CHAR : 
	fa_behance_square = "\uf1b5"
	# CHAR : 
	fa_bell = "\uf0f3"
	# CHAR : 
	fa_bell_concierge = "\uee2b"
	# CHAR : 
	fa_bell_o = "\uf0a2"
	# CHAR : 
	fa_bell_slash = "\uf1f6"
	# CHAR : 
	fa_bell_slash_o = "\uf1f7"
	# CHAR : 
	fa_bezier_curve = "\uee24"
	# CHAR : 
	fa_bicycle = "\uf206"
	# CHAR : 
	fa_bimobject = "\uf0ff"
	# CHAR : 
	fa_binoculars = "\uf1e5"
	# CHAR : 
	fa_biohazard = "\uef35"
	# CHAR : 
	fa_birthday_cake = "\uf1fd"
	# CHAR : 
	fa_bitbucket = "\uf171"
	# CHAR : 
	fa_bitbucket_square = "\uf172"
	# CHAR : 
	fa_bitcoin = "\uf10f"
	# CHAR : 
	fa_bity = "\uf116"
	# CHAR : 
	fa_black_tie = "\uf27e"
	# CHAR : 
	fa_blackberry = "\uf117"
	# CHAR : 
	fa_blender = "\uede1"
	# CHAR : 
	fa_blender_phone = "\ueeea"
	# CHAR : 
	fa_blind = "\uf29d"
	# CHAR : 
	fa_blog = "\uef36"
	# CHAR : 
	fa_blogger = "\uf11f"
	# CHAR : 
	fa_blogger_b = "\uf12f"
	# CHAR : 
	fa_bluetooth = "\uf293"
	# CHAR : 
	fa_bluetooth_b = "\uf294"
	# CHAR : 
	fa_bold = "\uf032"
	# CHAR : 
	fa_bolt = "\uf0e7"
	# CHAR : 
	fa_bomb = "\uf1e2"
	# CHAR : 
	fa_bone = "\uee9a"
	# CHAR : 
	fa_bong = "\uee25"
	# CHAR : 
	fa_book = "\uf02d"
	# CHAR : 
	fa_book_atlas = "\uee21"
	# CHAR : 
	fa_book_bible = "\ueebe"
	# CHAR : 
	fa_book_journal_whills = "\ueecd"
	# CHAR : 
	fa_book_medical = "\uef78"
	# CHAR : 
	fa_book_open = "\uede2"
	# CHAR : 
	fa_book_open_reader = "\uee9b"
	# CHAR : 
	fa_book_quran = "\ueedc"
	# CHAR : 
	fa_book_skull = "\ueeeb"
	# CHAR : 
	fa_book_tanakh = "\uef8e"
	# CHAR : 
	fa_bookmark = "\uf02e"
	# CHAR : 
	fa_bookmark_o = "\uf097"
	# CHAR : 
	fa_bootstrap = "\uef95"
	# CHAR : 
	fa_border_all = "\uefa3"
	# CHAR : 
	fa_border_none = "\uefa4"
	# CHAR : 
	fa_border_top_left = "\uefa5"
	# CHAR : 
	fa_bowling_ball = "\ued5e"
	# CHAR : 
	fa_box = "\ued75"
	# CHAR : 
	fa_box_archive = "\uf187"
	# CHAR : 
	fa_box_open = "\ued95"
	# CHAR : 
	fa_boxes_stacked = "\ued76"
	# CHAR : 
	fa_braille = "\uf2a1"
	# CHAR : 
	fa_brain = "\uee9c"
	# CHAR : 
	fa_bread_slice = "\uef79"
	# CHAR : 
	fa_briefcase = "\uf0b1"
	# CHAR : 
	fa_briefcase_medical = "\ued77"
	# CHAR : 
	fa_broom = "\uede4"
	# CHAR : 
	fa_broom_ball = "\ued6e"
	# CHAR : 
	fa_brush = "\uee26"
	# CHAR : 
	fa_btc = "\uf15a"
	# CHAR : 
	fa_buffer = "\uef96"
	# CHAR : 
	fa_bug = "\uf188"
	# CHAR : 
	fa_building = "\uf1ad"
	# CHAR : 
	fa_building_columns = "\uf19c"
	# CHAR : 
	fa_building_o = "\uf0f7"
	# CHAR : 
	fa_bullhorn = "\uf0a1"
	# CHAR : 
	fa_bullseye = "\uf140"
	# CHAR : 
	fa_burger = "\uef82"
	# CHAR : 
	fa_buromobelexperte = "\uf13f"
	# CHAR : 
	fa_bus = "\uf207"
	# CHAR : 
	fa_bus_simple = "\uee27"
	# CHAR : 
	fa_business_time = "\ueebf"
	# CHAR : 
	fa_buy_n_large = "\uefb6"
	# CHAR : 
	fa_buysellads = "\uf20d"
	# CHAR : 
	fa_cab = "\uf1ba"
	# CHAR : 
	fa_cable_car = "\uef71"
	# CHAR : 
	fa_cake_candles = "\uf1fd"
	# CHAR : 
	fa_calculator = "\uf1ec"
	# CHAR : 
	fa_calendar = "\uf073"
	# CHAR : 
	fa_calendar_check = "\uf274"
	# CHAR : 
	fa_calendar_check_o = "\uf274"
	# CHAR : 
	fa_calendar_day = "\uef37"
	# CHAR : 
	fa_calendar_days = "\uf073"
	# CHAR : 
	fa_calendar_minus = "\uf272"
	# CHAR : 
	fa_calendar_minus_o = "\uf272"
	# CHAR : 
	fa_calendar_o = "\uf133"
	# CHAR : 
	fa_calendar_plus = "\uf271"
	# CHAR : 
	fa_calendar_plus_o = "\uf271"
	# CHAR : 
	fa_calendar_times_o = "\uf273"
	# CHAR : 
	fa_calendar_week = "\uef38"
	# CHAR : 
	fa_calendar_xmark = "\uf273"
	# CHAR : 
	fa_camera = "\uf030"
	# CHAR : 
	fa_camera_retro = "\uf083"
	# CHAR : 
	fa_campground = "\ueeec"
	# CHAR : 
	fa_canadian_maple_leaf = "\uef39"
	# CHAR : 
	fa_candy_cane = "\uef3a"
	# CHAR : 
	fa_cannabis = "\uee28"
	# CHAR : 
	fa_capsules = "\ued79"
	# CHAR : 
	fa_car = "\uf1b9"
	# CHAR : 
	fa_car_battery = "\uee9e"
	# CHAR : 
	fa_car_burst = "\uee9f"
	# CHAR : 
	fa_car_rear = "\uee9d"
	# CHAR : 
	fa_car_side = "\ueea0"
	# CHAR : 
	fa_caravan = "\uefc1"
	# CHAR : 
	fa_caret_down = "\uf0d7"
	# CHAR : 
	fa_caret_left = "\uf0d9"
	# CHAR : 
	fa_caret_right = "\uf0da"
	# CHAR : 
	fa_caret_square_o_down = "\uf150"
	# CHAR : 
	fa_caret_square_o_left = "\uf191"
	# CHAR : 
	fa_caret_square_o_right = "\uf152"
	# CHAR : 
	fa_caret_square_o_up = "\uf151"
	# CHAR : 
	fa_caret_up = "\uf0d8"
	# CHAR : 
	fa_carrot = "\uef3b"
	# CHAR : 
	fa_cart_arrow_down = "\uf218"
	# CHAR : 
	fa_cart_flatbed = "\ued7f"
	# CHAR : 
	fa_cart_flatbed_suitcase = "\uee66"
	# CHAR : 
	fa_cart_plus = "\uf217"
	# CHAR : 
	fa_cart_shopping = "\uf07a"
	# CHAR : 
	fa_cash_register = "\uef3c"
	# CHAR : 
	fa_cat = "\ueeed"
	# CHAR : 
	fa_cc = "\uf20a"
	# CHAR : 
	fa_cc_amazon_pay = "\ued57"
	# CHAR : 
	fa_cc_amex = "\uf1f3"
	# CHAR : 
	fa_cc_apple_pay = "\ued42"
	# CHAR : 
	fa_cc_diners_club = "\uf24c"
	# CHAR : 
	fa_cc_discover = "\uf1f2"
	# CHAR : 
	fa_cc_jcb = "\uf24b"
	# CHAR : 
	fa_cc_mastercard = "\uf1f1"
	# CHAR : 
	fa_cc_paypal = "\uf1f4"
	# CHAR : 
	fa_cc_stripe = "\uf1f5"
	# CHAR : 
	fa_cc_visa = "\uf1f0"
	# CHAR : 
	fa_centercode = "\uf14f"
	# CHAR : 
	fa_centos = "\uef3d"
	# CHAR : 
	fa_certificate = "\uf0a3"
	# CHAR : 
	fa_chain = "\uf0c1"
	# CHAR : 
	fa_chain_broken = "\uf127"
	# CHAR : 
	fa_chair = "\ueeee"
	# CHAR : 
	fa_chalkboard = "\uede5"
	# CHAR : 
	fa_chalkboard_user = "\uede6"
	# CHAR : 
	fa_champagne_glasses = "\uef49"
	# CHAR : 
	fa_charging_station = "\ueea1"
	# CHAR : 
	fa_chart_area = "\uf1fe"
	# CHAR : 
	fa_chart_bar = "\uf080"
	# CHAR : 
	fa_chart_line = "\uf201"
	# CHAR : 
	fa_chart_pie = "\uf200"
	# CHAR : 
	fa_check = "\uf00c"
	# CHAR : 
	fa_check_circle = "\uf058"
	# CHAR : 
	fa_check_circle_o = "\uf05d"
	# CHAR : 
	fa_check_double = "\uee29"
	# CHAR : 
	fa_check_square = "\uf14a"
	# CHAR : 
	fa_check_square_o = "\uf046"
	# CHAR : 
	fa_check_to_slot = "\uef2f"
	# CHAR : 
	fa_cheese = "\uef7a"
	# CHAR : 
	fa_chess = "\ued5f"
	# CHAR : 
	fa_chess_bishop = "\ued60"
	# CHAR : 
	fa_chess_board = "\ued61"
	# CHAR : 
	fa_chess_king = "\ued62"
	# CHAR : 
	fa_chess_knight = "\ued63"
	# CHAR : 
	fa_chess_pawn = "\ued64"
	# CHAR : 
	fa_chess_queen = "\ued65"
	# CHAR : 
	fa_chess_rook = "\ued66"
	# CHAR : 
	fa_chevron_circle_down = "\uf13a"
	# CHAR : 
	fa_chevron_circle_left = "\uf137"
	# CHAR : 
	fa_chevron_circle_right = "\uf138"
	# CHAR : 
	fa_chevron_circle_up = "\uf139"
	# CHAR : 
	fa_chevron_down = "\uf078"
	# CHAR : 
	fa_chevron_left = "\uf053"
	# CHAR : 
	fa_chevron_right = "\uf054"
	# CHAR : 
	fa_chevron_up = "\uf077"
	# CHAR : 
	fa_child = "\uf1ae"
	# CHAR : 
	fa_chrome = "\uf268"
	# CHAR : 
	fa_chromecast = "\uef97"
	# CHAR : 
	fa_church = "\uede7"
	# CHAR : 
	fa_circle = "\uf111"
	# CHAR : 
	fa_circle_arrow_down = "\uf0ab"
	# CHAR : 
	fa_circle_arrow_left = "\uf0a8"
	# CHAR : 
	fa_circle_arrow_right = "\uf0a9"
	# CHAR : 
	fa_circle_arrow_up = "\uf0aa"
	# CHAR : 
	fa_circle_check = "\uf05d"
	# CHAR : 
	fa_circle_chevron_down = "\uf13a"
	# CHAR : 
	fa_circle_chevron_left = "\uf137"
	# CHAR : 
	fa_circle_chevron_right = "\uf138"
	# CHAR : 
	fa_circle_chevron_up = "\uf139"
	# CHAR : 
	fa_circle_dollar_to_slot = "\ued98"
	# CHAR : 
	fa_circle_dot = "\uf192"
	# CHAR : 
	fa_circle_down = "\uf01a"
	# CHAR : 
	fa_circle_exclamation = "\uf06a"
	# CHAR : 
	fa_circle_h = "\ued83"
	# CHAR : 
	fa_circle_half_stroke = "\uf042"
	# CHAR : 
	fa_circle_info = "\uf05a"
	# CHAR : 
	fa_circle_left = "\uf190"
	# CHAR : 
	fa_circle_minus = "\uf056"
	# CHAR : 
	fa_circle_notch = "\uf1ce"
	# CHAR : 
	fa_circle_o = "\uf10c"
	# CHAR : 
	fa_circle_o_notch = "\uf1ce"
	# CHAR : 
	fa_circle_pause = "\uf28b"
	# CHAR : 
	fa_circle_play = "\uf144"
	# CHAR : 
	fa_circle_plus = "\uf055"
	# CHAR : 
	fa_circle_question = "\uf059"
	# CHAR : 
	fa_circle_radiation = "\uef5b"
	# CHAR : 
	fa_circle_right = "\uf18e"
	# CHAR : 
	fa_circle_stop = "\uf28d"
	# CHAR : 
	fa_circle_thin = "\uf1db"
	# CHAR : 
	fa_circle_up = "\uf01b"
	# CHAR : 
	fa_circle_user = "\uf2bd"
	# CHAR : 
	fa_circle_xmark = "\uf05c"
	# CHAR : 
	fa_city = "\ueec0"
	# CHAR : 
	fa_clipboard = "\uf0ea"
	# CHAR : 
	fa_clipboard_alt = "\uf07f"
	# CHAR : 
	fa_clipboard_check = "\ued7a"
	# CHAR : 
	fa_clipboard_list = "\ued7b"
	# CHAR : 
	fa_clipboard_user = "\uef7c"
	# CHAR : 
	fa_clock = "\uf017"
	# CHAR : 
	fa_clock_o = "\uf017"
	# CHAR : 
	fa_clock_rotate_left = "\uf1da"
	# CHAR : 
	fa_clone = "\uf24d"
	# CHAR : 
	fa_close = "\uf00d"
	# CHAR : 
	fa_closed_captioning = "\uf20a"
	# CHAR : 
	fa_cloud = "\uf0c2"
	# CHAR : 
	fa_cloud_arrow_down = "\uf0ed"
	# CHAR : 
	fa_cloud_arrow_up = "\uf0ee"
	# CHAR : 
	fa_cloud_bolt = "\uef2c"
	# CHAR : 
	fa_cloud_download = "\uf0ed"
	# CHAR : 
	fa_cloud_meatball = "\uef1a"
	# CHAR : 
	fa_cloud_moon = "\ueeef"
	# CHAR : 
	fa_cloud_moon_rain = "\uef1b"
	# CHAR : 
	fa_cloud_rain = "\uef1c"
	# CHAR : 
	fa_cloud_showers_heavy = "\uef1d"
	# CHAR : 
	fa_cloud_sun = "\ueef0"
	# CHAR : 
	fa_cloud_sun_rain = "\uef1e"
	# CHAR : 
	fa_cloud_upload = "\uf0ee"
	# CHAR : 
	fa_cloudscale = "\uf15f"
	# CHAR : 
	fa_cloudsmith = "\uf167"
	# CHAR : 
	fa_cloudversify = "\uf16f"
	# CHAR : 
	fa_cny = "\uf157"
	# CHAR : 
	fa_code = "\uf121"
	# CHAR : 
	fa_code_branch = "\uf126"
	# CHAR : 
	fa_code_commit = "\uf172"
	# CHAR : 
	fa_code_fork = "\uf126"
	# CHAR : 
	fa_code_merge = "\uf17f"
	# CHAR : 
	fa_codepen = "\uf1cb"
	# CHAR : 
	fa_codiepie = "\uf284"
	# CHAR : 
	fa_coffee = "\uf0f4"
	# CHAR : 
	fa_cog = "\uf013"
	# CHAR : 
	fa_cogs = "\uf085"
	# CHAR : 
	fa_coins = "\uede8"
	# CHAR : 
	fa_columns = "\uf0db"
	# CHAR : 
	fa_comment = "\uf075"
	# CHAR : 
	fa_comment_dollar = "\ueec1"
	# CHAR : 
	fa_comment_dots = "\uf27b"
	# CHAR : 
	fa_comment_medical = "\uef7d"
	# CHAR : 
	fa_comment_o = "\uf0e5"
	# CHAR : 
	fa_comment_slash = "\ued96"
	# CHAR : 
	fa_comment_sms = "\uef68"
	# CHAR : 
	fa_commenting = "\uf27a"
	# CHAR : 
	fa_commenting_o = "\uf27b"
	# CHAR : 
	fa_comments = "\uf086"
	# CHAR : 
	fa_comments_dollar = "\ueec2"
	# CHAR : 
	fa_comments_o = "\uf0e6"
	# CHAR : 
	fa_compact_disc = "\uede9"
	# CHAR : 
	fa_compass = "\uf14e"
	# CHAR : 
	fa_compass_drafting = "\uee31"
	# CHAR : 
	fa_compress = "\uf066"
	# CHAR : 
	fa_computer_mouse = "\uefba"
	# CHAR : 
	fa_confluence = "\uef3f"
	# CHAR : 
	fa_connectdevelop = "\uf20e"
	# CHAR : 
	fa_contao = "\uf26d"
	# CHAR : 
	fa_cookie = "\uee2c"
	# CHAR : 
	fa_cookie_bite = "\uee2d"
	# CHAR : 
	fa_copy = "\uf0c5"
	# CHAR : 
	fa_copyright = "\uf1f9"
	# CHAR : 
	fa_cotton_bureau = "\uefb5"
	# CHAR : 
	fa_couch = "\ued97"
	# CHAR : 
	fa_cow = "\ueef1"
	# CHAR : 
	fa_cpanel = "\uf18f"
	# CHAR : 
	fa_creative_commons = "\uf25e"
	# CHAR : 
	fa_creative_commons_by = "\uedb1"
	# CHAR : 
	fa_creative_commons_nc = "\uedb2"
	# CHAR : 
	fa_creative_commons_nc_eu = "\uedb3"
	# CHAR : 
	fa_creative_commons_nc_jp = "\uedb4"
	# CHAR : 
	fa_creative_commons_nd = "\uedb5"
	# CHAR : 
	fa_creative_commons_pd = "\uedb6"
	# CHAR : 
	fa_creative_commons_pd_alt = "\uedb7"
	# CHAR : 
	fa_creative_commons_remix = "\uedb8"
	# CHAR : 
	fa_creative_commons_sa = "\uedb9"
	# CHAR : 
	fa_creative_commons_sampling = "\uedba"
	# CHAR : 
	fa_creative_commons_sampling_plus = "\uedbb"
	# CHAR : 
	fa_creative_commons_share = "\uedbc"
	# CHAR : 
	fa_creative_commons_zero = "\uedbd"
	# CHAR : 
	fa_credit_card = "\uf09d"
	# CHAR : 
	fa_credit_card_alt = "\uf283"
	# CHAR : 
	fa_critical_role = "\ueef2"
	# CHAR : 
	fa_crop = "\uf125"
	# CHAR : 
	fa_crop_simple = "\uee2e"
	# CHAR : 
	fa_cross = "\ueec3"
	# CHAR : 
	fa_crosshairs = "\uf05b"
	# CHAR : 
	fa_crow = "\uedea"
	# CHAR : 
	fa_crown = "\uedeb"
	# CHAR : 
	fa_crutch = "\uef7e"
	# CHAR : 
	fa_css3 = "\uf13c"
	# CHAR : 
	fa_css3_alt = "\uf19f"
	# CHAR : 
	fa_cube = "\uf1b2"
	# CHAR : 
	fa_cubes = "\uf1b3"
	# CHAR : 
	fa_cut = "\uf0c4"
	# CHAR : 
	fa_cutlery = "\uf0f5"
	# CHAR : 
	fa_cuttlefish = "\uf1af"
	# CHAR : 
	fa_d_and_d = "\uf1bf"
	# CHAR : 
	fa_d_and_d_beyond = "\ueef3"
	# CHAR : 
	fa_dashboard = "\uf0e4"
	# CHAR : 
	fa_dashcube = "\uf210"
	# CHAR : 
	fa_database = "\uf1c0"
	# CHAR : 
	fa_deaf = "\uf2a4"
	# CHAR : 
	fa_deafness = "\uf2a4"
	# CHAR : 
	fa_dedent = "\uf03b"
	# CHAR : 
	fa_delete_left = "\uee23"
	# CHAR : 
	fa_delicious = "\uf1a5"
	# CHAR : 
	fa_democrat = "\uef1f"
	# CHAR : 
	fa_deploydog = "\uf1cf"
	# CHAR : 
	fa_deskpro = "\uf1df"
	# CHAR : 
	fa_desktop = "\uf108"
	# CHAR : 
	fa_dev = "\ueef4"
	# CHAR : 
	fa_deviantart = "\uf1bd"
	# CHAR : 
	fa_dharmachakra = "\ueec4"
	# CHAR : 
	fa_dhl = "\uef40"
	# CHAR : 
	fa_diagram_project = "\uefce"
	# CHAR : 
	fa_diamond = "\uf29f"
	# CHAR : 
	fa_diamond_turn_right = "\ueea2"
	# CHAR : 
	fa_diaspora = "\uef41"
	# CHAR : 
	fa_dice = "\uedec"
	# CHAR : 
	fa_dice_d20 = "\ueef5"
	# CHAR : 
	fa_dice_d6 = "\ueef6"
	# CHAR : 
	fa_dice_five = "\ueded"
	# CHAR : 
	fa_dice_four = "\uedee"
	# CHAR : 
	fa_dice_one = "\uedef"
	# CHAR : 
	fa_dice_six = "\uedf0"
	# CHAR : 
	fa_dice_three = "\uedf1"
	# CHAR : 
	fa_dice_two = "\uedf2"
	# CHAR : 
	fa_digg = "\uf1a6"
	# CHAR : 
	fa_digital_ocean = "\uf1ef"
	# CHAR : 
	fa_discord = "\uf1ff"
	# CHAR : 
	fa_discourse = "\uf20c"
	# CHAR : 
	fa_disease = "\uef7f"
	# CHAR : 
	fa_divide = "\uedf3"
	# CHAR : 
	fa_dna = "\ued7d"
	# CHAR : 
	fa_dochub = "\uf20f"
	# CHAR : 
	fa_docker = "\uf21f"
	# CHAR : 
	fa_dog = "\ueef7"
	# CHAR : 
	fa_dollar = "\uf155"
	# CHAR : 
	fa_dollar_sign = "\uf155"
	# CHAR : 
	fa_dolly = "\ued7e"
	# CHAR : 
	fa_door_closed = "\uedf4"
	# CHAR : 
	fa_door_open = "\uedf5"
	# CHAR : 
	fa_dot_circle_o = "\uf192"
	# CHAR : 
	fa_dove = "\ued99"
	# CHAR : 
	fa_down_left_and_up_right_to_center = "\ued4d"
	# CHAR : 
	fa_down_long = "\uf03f"
	# CHAR : 
	fa_download = "\uf019"
	# CHAR : 
	fa_draft2digital = "\uf220"
	# CHAR : 
	fa_dragon = "\ueef8"
	# CHAR : 
	fa_draw_polygon = "\ueea3"
	# CHAR : 
	fa_dribbble = "\uf17d"
	# CHAR : 
	fa_drivers_license = "\uf2c2"
	# CHAR : 
	fa_drivers_license_o = "\uf2c3"
	# CHAR : 
	fa_dropbox = "\uf16b"
	# CHAR : 
	fa_droplet = "\uf043"
	# CHAR : 
	fa_droplet_slash = "\uee8e"
	# CHAR : 
	fa_drum = "\uee32"
	# CHAR : 
	fa_drum_steelpan = "\uee33"
	# CHAR : 
	fa_drumstick_bite = "\ueef9"
	# CHAR : 
	fa_drupal = "\uf1a9"
	# CHAR : 
	fa_dumbbell = "\ued67"
	# CHAR : 
	fa_dumpster = "\uef42"
	# CHAR : 
	fa_dumpster_fire = "\uef43"
	# CHAR : 
	fa_dungeon = "\ueefa"
	# CHAR : 
	fa_dyalog = "\uf22f"
	# CHAR : 
	fa_ear_deaf = "\uf2a4"
	# CHAR : 
	fa_ear_listen = "\uf2a2"
	# CHAR : 
	fa_earlybirds = "\uf230"
	# CHAR : 
	fa_earth_africa = "\uee45"
	# CHAR : 
	fa_earth_americas = "\uee46"
	# CHAR : 
	fa_earth_asia = "\uee47"
	# CHAR : 
	fa_earth_europe = "\uef4b"
	# CHAR : 
	fa_ebay = "\uedbe"
	# CHAR : 
	fa_edge = "\uf282"
	# CHAR : 
	fa_edit = "\uf044"
	# CHAR : 
	fa_eercast = "\uf2da"
	# CHAR : 
	fa_egg = "\uef80"
	# CHAR : 
	fa_eject = "\uf052"
	# CHAR : 
	fa_elementor = "\ued5a"
	# CHAR : 
	fa_ellipsis = "\uf141"
	# CHAR : 
	fa_ellipsis_h = "\uf141"
	# CHAR : 
	fa_ellipsis_v = "\uf142"
	# CHAR : 
	fa_ellipsis_vertical = "\uf142"
	# CHAR : 
	fa_ello = "\ueea4"
	# CHAR : 
	fa_ember = "\ued4e"
	# CHAR : 
	fa_empire = "\uf1d1"
	# CHAR : 
	fa_envelope = "\uf0e0"
	# CHAR : 
	fa_envelope_o = "\uf003"
	# CHAR : 
	fa_envelope_open = "\uf2b6"
	# CHAR : 
	fa_envelope_open_o = "\uf2b7"
	# CHAR : 
	fa_envelope_open_text = "\ueec5"
	# CHAR : 
	fa_envelope_square = "\uf199"
	# CHAR : 
	fa_envelopes_bulk = "\ueed1"
	# CHAR : 
	fa_envira = "\uf299"
	# CHAR : 
	fa_equals = "\uedf6"
	# CHAR : 
	fa_eraser = "\uf12d"
	# CHAR : 
	fa_erlang = "\uf23f"
	# CHAR : 
	fa_ethereum = "\ued58"
	# CHAR : 
	fa_ethernet = "\uef44"
	# CHAR : 
	fa_etsy = "\uf2d7"
	# CHAR : 
	fa_eur = "\uf153"
	# CHAR : 
	fa_euro = "\uf153"
	# CHAR : 
	fa_euro_sign = "\uf153"
	# CHAR : 
	fa_evernote = "\uef98"
	# CHAR : 
	fa_exchange = "\uf0ec"
	# CHAR : 
	fa_exclamation = "\uf12a"
	# CHAR : 
	fa_exclamation_circle = "\uf06a"
	# CHAR : 
	fa_exclamation_triangle = "\uf071"
	# CHAR : 
	fa_expand = "\uf065"
	# CHAR : 
	fa_expeditedssl = "\uf23e"
	# CHAR : 
	fa_external_link = "\uf08e"
	# CHAR : 
	fa_external_link_square = "\uf14c"
	# CHAR : 
	fa_eye = "\uf06e"
	# CHAR : 
	fa_eye_dropper = "\uf1fb"
	# CHAR : 
	fa_eye_low_vision = "\uf2a8"
	# CHAR : 
	fa_eye_slash = "\uf070"
	# CHAR : 
	fa_eyedropper = "\uf1fb"
	# CHAR : 
	fa_fa = "\uf2b4"
	# CHAR : 
	fa_face_angry = "\uee1f"
	# CHAR : 
	fa_face_dizzy = "\uee30"
	# CHAR : 
	fa_face_flushed = "\uee42"
	# CHAR : 
	fa_face_frown = "\uf119"
	# CHAR : 
	fa_face_frown_open = "\uee43"
	# CHAR : 
	fa_face_grimace = "\uee48"
	# CHAR : 
	fa_face_grin = "\uee49"
	# CHAR : 
	fa_face_grin_beam = "\uee4b"
	# CHAR : 
	fa_face_grin_beam_sweat = "\uee4c"
	# CHAR : 
	fa_face_grin_hearts = "\uee4d"
	# CHAR : 
	fa_face_grin_squint = "\uee4e"
	# CHAR : 
	fa_face_grin_squint_tears = "\uee4f"
	# CHAR : 
	fa_face_grin_stars = "\uee50"
	# CHAR : 
	fa_face_grin_tears = "\uee51"
	# CHAR : 
	fa_face_grin_tongue = "\uee52"
	# CHAR : 
	fa_face_grin_tongue_squint = "\uee53"
	# CHAR : 
	fa_face_grin_tongue_wink = "\uee54"
	# CHAR : 
	fa_face_grin_wide = "\uee4a"
	# CHAR : 
	fa_face_grin_wink = "\uee55"
	# CHAR : 
	fa_face_kiss = "\uee5f"
	# CHAR : 
	fa_face_kiss_beam = "\uee60"
	# CHAR : 
	fa_face_kiss_wink_heart = "\uee61"
	# CHAR : 
	fa_face_laugh = "\uee62"
	# CHAR : 
	fa_face_laugh_beam = "\uee63"
	# CHAR : 
	fa_face_laugh_squint = "\uee64"
	# CHAR : 
	fa_face_laugh_wink = "\uee65"
	# CHAR : 
	fa_face_meh = "\uf11a"
	# CHAR : 
	fa_face_meh_blank = "\uee6d"
	# CHAR : 
	fa_face_rolling_eyes = "\uee6e"
	# CHAR : 
	fa_face_sad_cry = "\uee7b"
	# CHAR : 
	fa_face_sad_tear = "\uee7c"
	# CHAR : 
	fa_face_smile = "\uf118"
	# CHAR : 
	fa_face_smile_beam = "\uee80"
	# CHAR : 
	fa_face_smile_wink = "\ueda9"
	# CHAR : 
	fa_face_surprise = "\uee89"
	# CHAR : 
	fa_face_tired = "\uee8f"
	# CHAR : 
	fa_facebook = "\uf09a"
	# CHAR : 
	fa_facebook_f = "\uf24f"
	# CHAR : 
	fa_facebook_messenger = "\uf25f"
	# CHAR : 
	fa_facebook_official = "\uf230"
	# CHAR : 
	fa_facebook_square = "\uf082"
	# CHAR : 
	fa_fan = "\uefa7"
	# CHAR : 
	fa_fantasy_flight_games = "\ueefb"
	# CHAR : 
	fa_fast_backward = "\uf049"
	# CHAR : 
	fa_fast_forward = "\uf050"
	# CHAR : 
	fa_fax = "\uf1ac"
	# CHAR : 
	fa_feather = "\uedf7"
	# CHAR : 
	fa_feather_pointed = "\uee34"
	# CHAR : 
	fa_fedex = "\uef45"
	# CHAR : 
	fa_fedora = "\uef46"
	# CHAR : 
	fa_feed = "\uf09e"
	# CHAR : 
	fa_female = "\uf182"
	# CHAR : 
	fa_fighter_jet = "\uf0fb"
	# CHAR : 
	fa_figma = "\uef47"
	# CHAR : 
	fa_file = "\uf15b"
	# CHAR : 
	fa_file_archive_o = "\uf1c6"
	# CHAR : 
	fa_file_arrow_down = "\uee36"
	# CHAR : 
	fa_file_arrow_up = "\uee3d"
	# CHAR : 
	fa_file_audio = "\uf1c7"
	# CHAR : 
	fa_file_audio_o = "\uf1c7"
	# CHAR : 
	fa_file_code = "\uf1c9"
	# CHAR : 
	fa_file_code_o = "\uf1c9"
	# CHAR : 
	fa_file_contract = "\uee35"
	# CHAR : 
	fa_file_csv = "\ueefc"
	# CHAR : 
	fa_file_excel = "\uf1c3"
	# CHAR : 
	fa_file_excel_o = "\uf1c3"
	# CHAR : 
	fa_file_export = "\uee37"
	# CHAR : 
	fa_file_image = "\uf1c5"
	# CHAR : 
	fa_file_image_o = "\uf1c5"
	# CHAR : 
	fa_file_import = "\uee38"
	# CHAR : 
	fa_file_invoice = "\uee39"
	# CHAR : 
	fa_file_invoice_dollar = "\uee3a"
	# CHAR : 
	fa_file_lines = "\uf15c"
	# CHAR : 
	fa_file_medical = "\ued80"
	# CHAR : 
	fa_file_movie_o = "\uf1c8"
	# CHAR : 
	fa_file_o = "\uf016"
	# CHAR : 
	fa_file_pdf = "\uf1c1"
	# CHAR : 
	fa_file_pdf_o = "\uf1c1"
	# CHAR : 
	fa_file_pen = "\uf05f"
	# CHAR : 
	fa_file_photo_o = "\uf1c5"
	# CHAR : 
	fa_file_picture_o = "\uf1c5"
	# CHAR : 
	fa_file_powerpoint = "\uf1c4"
	# CHAR : 
	fa_file_powerpoint_o = "\uf1c4"
	# CHAR : 
	fa_file_prescription = "\uee3b"
	# CHAR : 
	fa_file_signature = "\uee3c"
	# CHAR : 
	fa_file_sound_o = "\uf1c7"
	# CHAR : 
	fa_file_text = "\uf15c"
	# CHAR : 
	fa_file_text_o = "\uf0f6"
	# CHAR : 
	fa_file_video = "\uf1c8"
	# CHAR : 
	fa_file_video_o = "\uf1c8"
	# CHAR : 
	fa_file_waveform = "\ued81"
	# CHAR : 
	fa_file_word = "\uf1c2"
	# CHAR : 
	fa_file_word_o = "\uf1c2"
	# CHAR : 
	fa_file_zip_o = "\uf1c6"
	# CHAR : 
	fa_file_zipper = "\uf1c6"
	# CHAR : 
	fa_files_o = "\uf0c5"
	# CHAR : 
	fa_fill = "\uee3e"
	# CHAR : 
	fa_fill_drip = "\uee3f"
	# CHAR : 
	fa_film = "\uf008"
	# CHAR : 
	fa_filter = "\uf0b0"
	# CHAR : 
	fa_filter_circle_dollar = "\ueec8"
	# CHAR : 
	fa_fingerprint = "\uee40"
	# CHAR : 
	fa_fire = "\uf06d"
	# CHAR : 
	fa_fire_extinguisher = "\uf134"
	# CHAR : 
	fa_fire_flame_curved = "\uef76"
	# CHAR : 
	fa_fire_flame_simple = "\ued78"
	# CHAR : 
	fa_firefox = "\uf269"
	# CHAR : 
	fa_first_order = "\uf2b0"
	# CHAR : 
	fa_first_order_alt = "\uedd4"
	# CHAR : 
	fa_firstdraft = "\uf262"
	# CHAR : 
	fa_fish = "\uee41"
	# CHAR : 
	fa_flag = "\uf024"
	# CHAR : 
	fa_flag_checkered = "\uf11e"
	# CHAR : 
	fa_flag_o = "\uf11d"
	# CHAR : 
	fa_flag_usa = "\uef20"
	# CHAR : 
	fa_flash = "\uf0e7"
	# CHAR : 
	fa_flask = "\uf0c3"
	# CHAR : 
	fa_flickr = "\uf16e"
	# CHAR : 
	fa_flipboard = "\ued68"
	# CHAR : 
	fa_floppy_disk = "\uf0c7"
	# CHAR : 
	fa_floppy_o = "\uf0c7"
	# CHAR : 
	fa_fly = "\ued43"
	# CHAR : 
	fa_folder = "\uf07b"
	# CHAR : 
	fa_folder_minus = "\ueec6"
	# CHAR : 
	fa_folder_o = "\uf114"
	# CHAR : 
	fa_folder_open = "\uf07c"
	# CHAR : 
	fa_folder_open_o = "\uf115"
	# CHAR : 
	fa_folder_plus = "\ueec7"
	# CHAR : 
	fa_folder_tree = "\uef81"
	# CHAR : 
	fa_font = "\uf031"
	# CHAR : 
	fa_font_awesome = "\uf2b4"
	# CHAR : 
	fa_fonticons = "\uf280"
	# CHAR : 
	fa_fonticons_fi = "\uf26f"
	# CHAR : 
	fa_football = "\ued69"
	# CHAR : 
	fa_fort_awesome = "\uf286"
	# CHAR : 
	fa_fort_awesome_alt = "\uf27f"
	# CHAR : 
	fa_forumbee = "\uf211"
	# CHAR : 
	fa_forward = "\uf04e"
	# CHAR : 
	fa_forward_fast = "\uf050"
	# CHAR : 
	fa_forward_step = "\uf051"
	# CHAR : 
	fa_foursquare = "\uf180"
	# CHAR : 
	fa_free_code_camp = "\uf2c5"
	# CHAR : 
	fa_freebsd = "\uf28f"
	# CHAR : 
	fa_frog = "\uedf8"
	# CHAR : 
	fa_frown_o = "\uf119"
	# CHAR : 
	fa_fulcrum = "\uedd5"
	# CHAR : 
	fa_futbol = "\uf1e3"
	# CHAR : 
	fa_futbol_o = "\uf1e3"
	# CHAR : 
	fa_galactic_republic = "\uedd6"
	# CHAR : 
	fa_galactic_senate = "\uedd7"
	# CHAR : 
	fa_gamepad = "\uf11b"
	# CHAR : 
	fa_gas_pump = "\uedf9"
	# CHAR : 
	fa_gauge = "\ueeb2"
	# CHAR : 
	fa_gauge_high = "\ued2f"
	# CHAR : 
	fa_gauge_simple = "\ueeb3"
	# CHAR : 
	fa_gauge_simple_high = "\uf0e4"
	# CHAR : 
	fa_gavel = "\uf0e3"
	# CHAR : 
	fa_gbp = "\uf154"
	# CHAR : 
	fa_ge = "\uf1d1"
	# CHAR : 
	fa_gear = "\uf013"
	# CHAR : 
	fa_gears = "\uf085"
	# CHAR : 
	fa_gem = "\uf219"
	# CHAR : 
	fa_genderless = "\uf22d"
	# CHAR : 
	fa_get_pocket = "\uf265"
	# CHAR : 
	fa_gg = "\uf260"
	# CHAR : 
	fa_gg_circle = "\uf261"
	# CHAR : 
	fa_ghost = "\ueefe"
	# CHAR : 
	fa_gift = "\uf06b"
	# CHAR : 
	fa_gifts = "\uef48"
	# CHAR : 
	fa_git = "\uf1d3"
	# CHAR : 
	fa_git_alt = "\uefa0"
	# CHAR : 
	fa_git_square = "\uf1d2"
	# CHAR : 
	fa_github = "\uf09b"
	# CHAR : 
	fa_github_alt = "\uf113"
	# CHAR : 
	fa_github_square = "\uf092"
	# CHAR : 
	fa_gitkraken = "\uf2ac"
	# CHAR : 
	fa_gitlab = "\uf296"
	# CHAR : 
	fa_gitter = "\ued50"
	# CHAR : 
	fa_gittip = "\uf184"
	# CHAR : 
	fa_glass = "\uf000"
	# CHAR : 
	fa_glasses = "\uedfa"
	# CHAR : 
	fa_glide = "\uf2a5"
	# CHAR : 
	fa_glide_g = "\uf2a6"
	# CHAR : 
	fa_globe = "\uf0ac"
	# CHAR : 
	fa_gofore = "\uf2af"
	# CHAR : 
	fa_golf_ball_tee = "\ued6a"
	# CHAR : 
	fa_goodreads = "\uf2bf"
	# CHAR : 
	fa_goodreads_g = "\uf2cf"
	# CHAR : 
	fa_google = "\uf1a0"
	# CHAR : 
	fa_google_drive = "\uf2df"
	# CHAR : 
	fa_google_play = "\uf2e1"
	# CHAR : 
	fa_google_plus = "\uf0d5"
	# CHAR : 
	fa_google_plus_circle = "\uf2b3"
	# CHAR : 
	fa_google_plus_official = "\uf2b3"
	# CHAR : 
	fa_google_plus_square = "\uf0d4"
	# CHAR : 
	fa_google_wallet = "\uf1ee"
	# CHAR : 
	fa_gopuram = "\ueec9"
	# CHAR : 
	fa_graduation_cap = "\uf19d"
	# CHAR : 
	fa_gratipay = "\uf184"
	# CHAR : 
	fa_grav = "\uf2d6"
	# CHAR : 
	fa_greater_than = "\uedfb"
	# CHAR : 
	fa_greater_than_equal = "\uedfc"
	# CHAR : 
	fa_grip = "\uee56"
	# CHAR : 
	fa_grip_lines = "\uef4c"
	# CHAR : 
	fa_grip_lines_vertical = "\uef4d"
	# CHAR : 
	fa_grip_vertical = "\uee57"
	# CHAR : 
	fa_gripfire = "\uf2e2"
	# CHAR : 
	fa_group = "\uf0c0"
	# CHAR : 
	fa_grunt = "\uf2e3"
	# CHAR : 
	fa_guitar = "\uef4e"
	# CHAR : 
	fa_gulp = "\uf2e4"
	# CHAR : 
	fa_h_square = "\uf0fd"
	# CHAR : 
	fa_hacker_news = "\uf1d4"
	# CHAR : 
	fa_hackerrank = "\ueea5"
	# CHAR : 
	fa_hammer = "\ueeff"
	# CHAR : 
	fa_hamsa = "\ueeca"
	# CHAR : 
	fa_hand = "\uf256"
	# CHAR : 
	fa_hand_back_fist = "\uf255"
	# CHAR : 
	fa_hand_dots = "\ued73"
	# CHAR : 
	fa_hand_fist = "\ueefd"
	# CHAR : 
	fa_hand_grab_o = "\uf255"
	# CHAR : 
	fa_hand_holding = "\ued9a"
	# CHAR : 
	fa_hand_holding_dollar = "\ued9c"
	# CHAR : 
	fa_hand_holding_droplet = "\ued9d"
	# CHAR : 
	fa_hand_holding_heart = "\ued9b"
	# CHAR : 
	fa_hand_lizard = "\uf258"
	# CHAR : 
	fa_hand_lizard_o = "\uf258"
	# CHAR : 
	fa_hand_middle_finger = "\uef83"
	# CHAR : 
	fa_hand_o_down = "\uf0a7"
	# CHAR : 
	fa_hand_o_left = "\uf0a5"
	# CHAR : 
	fa_hand_o_right = "\uf0a4"
	# CHAR : 
	fa_hand_o_up = "\uf0a6"
	# CHAR : 
	fa_hand_paper_o = "\uf256"
	# CHAR : 
	fa_hand_peace = "\uf25b"
	# CHAR : 
	fa_hand_peace_o = "\uf25b"
	# CHAR : 
	fa_hand_point_down = "\uf0a7"
	# CHAR : 
	fa_hand_point_left = "\uf0a5"
	# CHAR : 
	fa_hand_point_right = "\uf0a4"
	# CHAR : 
	fa_hand_point_up = "\uf0a6"
	# CHAR : 
	fa_hand_pointer = "\uf25a"
	# CHAR : 
	fa_hand_pointer_o = "\uf25a"
	# CHAR : 
	fa_hand_rock_o = "\uf255"
	# CHAR : 
	fa_hand_scissors = "\uf257"
	# CHAR : 
	fa_hand_scissors_o = "\uf257"
	# CHAR : 
	fa_hand_spock = "\uf259"
	# CHAR : 
	fa_hand_spock_o = "\uf259"
	# CHAR : 
	fa_hand_stop_o = "\uf256"
	# CHAR : 
	fa_hands = "\uf2a7"
	# CHAR : 
	fa_hands_asl_interpreting = "\uf2a3"
	# CHAR : 
	fa_hands_holding = "\ued9e"
	# CHAR : 
	fa_hands_praying = "\ueedb"
	# CHAR : 
	fa_handshake = "\uf2b5"
	# CHAR : 
	fa_handshake_angle = "\ued9f"
	# CHAR : 
	fa_handshake_o = "\uf2b5"
	# CHAR : 
	fa_handshake_simple = "\ueda0"
	# CHAR : 
	fa_hanukiah = "\uef00"
	# CHAR : 
	fa_hard_drive = "\uf0a0"
	# CHAR : 
	fa_hard_of_hearing = "\uf2a4"
	# CHAR : 
	fa_hashtag = "\uf292"
	# CHAR : 
	fa_hat_cowboy = "\uefb7"
	# CHAR : 
	fa_hat_cowboy_side = "\uefb8"
	# CHAR : 
	fa_hat_wizard = "\uef01"
	# CHAR : 
	fa_hdd_o = "\uf0a0"
	# CHAR : 
	fa_header = "\uf1dc"
	# CHAR : 
	fa_heading = "\uf1dc"
	# CHAR : 
	fa_headphones = "\uf025"
	# CHAR : 
	fa_headphones_simple = "\uee58"
	# CHAR : 
	fa_headset = "\uee59"
	# CHAR : 
	fa_heard_o = "\uf08a"
	# CHAR : 
	fa_heart = "\uf004"
	# CHAR : 
	fa_heart_crack = "\uef4f"
	# CHAR : 
	fa_heart_o = "\uf08a"
	# CHAR : 
	fa_heart_pulse = "\uf21e"
	# CHAR : 
	fa_heartbeat = "\uf21e"
	# CHAR : 
	fa_helicopter = "\uedfd"
	# CHAR : 
	fa_helmet_safety = "\uef84"
	# CHAR : 
	fa_highlighter = "\uee5a"
	# CHAR : 
	fa_hippo = "\uef03"
	# CHAR : 
	fa_hips = "\ued6b"
	# CHAR : 
	fa_hire_a_helper = "\uf2e6"
	# CHAR : 
	fa_history = "\uf1da"
	# CHAR : 
	fa_hockey_puck = "\ued6c"
	# CHAR : 
	fa_holly_berry = "\uef50"
	# CHAR : 
	fa_home = "\uf015"
	# CHAR : 
	fa_hooli = "\ued51"
	# CHAR : 
	fa_hornbill = "\uee5b"
	# CHAR : 
	fa_horse = "\uef04"
	# CHAR : 
	fa_horse_head = "\uef51"
	# CHAR : 
	fa_hospital = "\uf0f8"
	# CHAR : 
	fa_hospital_o = "\uf0f8"
	# CHAR : 
	fa_hospital_user = "\uef86"
	# CHAR : 
	fa_hot_tub_person = "\uee5c"
	# CHAR : 
	fa_hotdog = "\uef87"
	# CHAR : 
	fa_hotel = "\uf236"
	# CHAR : 
	fa_hotel_building = "\uee5d"
	# CHAR : 
	fa_hotjar = "\uf2e7"
	# CHAR : 
	fa_hourglass = "\uf254"
	# CHAR : 
	fa_hourglass_1 = "\uf251"
	# CHAR : 
	fa_hourglass_2 = "\uf252"
	# CHAR : 
	fa_hourglass_3 = "\uf253"
	# CHAR : 
	fa_hourglass_end = "\uf253"
	# CHAR : 
	fa_hourglass_half = "\uf252"
	# CHAR : 
	fa_hourglass_o = "\uf250"
	# CHAR : 
	fa_hourglass_start = "\uf251"
	# CHAR : 
	fa_house = "\uf015"
	# CHAR : 
	fa_house_chimney = "\uef85"
	# CHAR : 
	fa_house_chimney_crack = "\uef05"
	# CHAR : 
	fa_house_chimney_medical = "\uef7b"
	# CHAR : 
	fa_houzz = "\uf27c"
	# CHAR : 
	fa_hryvnia_sign = "\uef06"
	# CHAR : 
	fa_html5 = "\uf13b"
	# CHAR : 
	fa_hubspot = "\uf2e8"
	# CHAR : 
	fa_hurricane = "\uef21"
	# CHAR : 
	fa_i_cursor = "\uf246"
	# CHAR : 
	fa_ice_cream = "\uef88"
	# CHAR : 
	fa_icicles = "\uef52"
	# CHAR : 
	fa_icons = "\uefa8"
	# CHAR : 
	fa_id_badge = "\uf2c1"
	# CHAR : 
	fa_id_card = "\uf2c2"
	# CHAR : 
	fa_id_card_clip = "\ued84"
	# CHAR : 
	fa_id_card_o = "\uf2c3"
	# CHAR : 
	fa_igloo = "\uef53"
	# CHAR : 
	fa_ils = "\uf20b"
	# CHAR : 
	fa_image = "\uf03e"
	# CHAR : 
	fa_image_portrait = "\ued19"
	# CHAR : 
	fa_images = "\uf00f"
	# CHAR : 
	fa_imdb = "\uf2d8"
	# CHAR : 
	fa_inbox = "\uf01c"
	# CHAR : 
	fa_indent = "\uf03c"
	# CHAR : 
	fa_industry = "\uf275"
	# CHAR : 
	fa_infinity = "\uedfe"
	# CHAR : 
	fa_info = "\uf129"
	# CHAR : 
	fa_info_circle = "\uf05a"
	# CHAR : 
	fa_inr = "\uf156"
	# CHAR : 
	fa_instagram = "\uf16d"
	# CHAR : 
	fa_institution = "\uf19c"
	# CHAR : 
	fa_intercom = "\uef54"
	# CHAR : 
	fa_internet_explorer = "\uf26b"
	# CHAR : 
	fa_intersex = "\uf224"
	# CHAR : 
	fa_invision = "\uef55"
	# CHAR : 
	fa_ioxhost = "\uf208"
	# CHAR : 
	fa_italic = "\uf033"
	# CHAR : 
	fa_itch_io = "\uef99"
	# CHAR : 
	fa_itunes = "\uf2e9"
	# CHAR : 
	fa_itunes_note = "\uf2eb"
	# CHAR : 
	fa_java = "\uedaf"
	# CHAR : 
	fa_jedi = "\ueecc"
	# CHAR : 
	fa_jedi_order = "\uedd8"
	# CHAR : 
	fa_jenkins = "\uf2ec"
	# CHAR : 
	fa_jet_fighter = "\uf0fb"
	# CHAR : 
	fa_jira = "\uef56"
	# CHAR : 
	fa_joget = "\uf2ed"
	# CHAR : 
	fa_joint = "\uee5e"
	# CHAR : 
	fa_joomla = "\uf1aa"
	# CHAR : 
	fa_jpy = "\uf157"
	# CHAR : 
	fa_js = "\uf2ee"
	# CHAR : 
	fa_jsfiddle = "\uf1cc"
	# CHAR : 
	fa_kaaba = "\ueece"
	# CHAR : 
	fa_kaggle = "\ueea6"
	# CHAR : 
	fa_key = "\uf084"
	# CHAR : 
	fa_keybase = "\uedbf"
	# CHAR : 
	fa_keyboard = "\uf11c"
	# CHAR : 
	fa_keyboard_o = "\uf11c"
	# CHAR : 
	fa_keycdn = "\uf2f0"
	# CHAR : 
	fa_khanda = "\ueecf"
	# CHAR : 
	fa_kickstarter = "\uf2f3"
	# CHAR : 
	fa_kickstarter_k = "\uf2f4"
	# CHAR : 
	fa_kit_medical = "\ued82"
	# CHAR : 
	fa_kiwi_bird = "\uedff"
	# CHAR : 
	fa_korvue = "\ued59"
	# CHAR : 
	fa_krw = "\uf159"
	# CHAR : 
	fa_landmark = "\ueed0"
	# CHAR : 
	fa_landmark_dome = "\uef22"
	# CHAR : 
	fa_language = "\uf1ab"
	# CHAR : 
	fa_laptop = "\uf109"
	# CHAR : 
	fa_laptop_code = "\ueea7"
	# CHAR : 
	fa_laptop_medical = "\uef89"
	# CHAR : 
	fa_laravel = "\uf2f7"
	# CHAR : 
	fa_lastfm = "\uf202"
	# CHAR : 
	fa_lastfm_square = "\uf203"
	# CHAR : 
	fa_layer_group = "\ueea8"
	# CHAR : 
	fa_leaf = "\uf06c"
	# CHAR : 
	fa_leanpub = "\uf212"
	# CHAR : 
	fa_left_long = "\uf04f"
	# CHAR : 
	fa_left_right = "\uf08f"
	# CHAR : 
	fa_legal = "\uf0e3"
	# CHAR : 
	fa_lemon = "\uf094"
	# CHAR : 
	fa_lemon_o = "\uf094"
	# CHAR : 
	fa_less = "\ued48"
	# CHAR : 
	fa_less_than = "\uefc3"
	# CHAR : 
	fa_less_than_equal = "\uefc4"
	# CHAR : 
	fa_level_down = "\uf149"
	# CHAR : 
	fa_level_up = "\uf148"
	# CHAR : 
	fa_life_bouy = "\uf1cd"
	# CHAR : 
	fa_life_buoy = "\uf1cd"
	# CHAR : 
	fa_life_ring = "\uf1cd"
	# CHAR : 
	fa_life_saver = "\uf1cd"
	# CHAR : 
	fa_lightbulb = "\uf0eb"
	# CHAR : 
	fa_lightbulb_o = "\uf0eb"
	# CHAR : 
	fa_line = "\uf2fb"
	# CHAR : 
	fa_line_chart = "\uf201"
	# CHAR : 
	fa_link = "\uf0c1"
	# CHAR : 
	fa_link_slash = "\uf127"
	# CHAR : 
	fa_linkedin = "\uf0e1"
	# CHAR : 
	fa_linkedin_in = "\uf0e1"
	# CHAR : 
	fa_linkedin_square = "\uf08c"
	# CHAR : 
	fa_linode = "\uf2b8"
	# CHAR : 
	fa_linux = "\uf17c"
	# CHAR : 
	fa_lira_sign = "\uf195"
	# CHAR : 
	fa_list = "\uf03a"
	# CHAR : 
	fa_list_alt = "\uf022"
	# CHAR : 
	fa_list_check = "\uf0ae"
	# CHAR : 
	fa_list_ol = "\uf0cb"
	# CHAR : 
	fa_list_ul = "\uf0ca"
	# CHAR : 
	fa_location_arrow = "\uf124"
	# CHAR : 
	fa_location_crosshairs = "\ueea9"
	# CHAR : 
	fa_location_dot = "\ued00"
	# CHAR : 
	fa_location_pin = "\uf041"
	# CHAR : 
	fa_lock = "\uf023"
	# CHAR : 
	fa_lock_open = "\uf2fc"
	# CHAR : 
	fa_long_arrow_down = "\uf175"
	# CHAR : 
	fa_long_arrow_left = "\uf177"
	# CHAR : 
	fa_long_arrow_right = "\uf178"
	# CHAR : 
	fa_long_arrow_up = "\uf176"
	# CHAR : 
	fa_low_vision = "\uf2a8"
	# CHAR : 
	fa_lungs = "\ueeaa"
	# CHAR : 
	fa_lyft = "\uf2fd"
	# CHAR : 
	fa_magento = "\uf2ff"
	# CHAR : 
	fa_magic = "\uf0d0"
	# CHAR : 
	fa_magnet = "\uf076"
	# CHAR : 
	fa_magnifying_glass = "\uf002"
	# CHAR : 
	fa_magnifying_glass_dollar = "\ueedd"
	# CHAR : 
	fa_magnifying_glass_location = "\ueede"
	# CHAR : 
	fa_magnifying_glass_minus = "\uf010"
	# CHAR : 
	fa_magnifying_glass_plus = "\uf00e"
	# CHAR : 
	fa_mail_forward = "\uf064"
	# CHAR : 
	fa_mail_reply = "\uf112"
	# CHAR : 
	fa_mail_reply_all = "\uf122"
	# CHAR : 
	fa_mailchimp = "\uee67"
	# CHAR : 
	fa_male = "\uf183"
	# CHAR : 
	fa_mandalorian = "\uedd9"
	# CHAR : 
	fa_map = "\uf279"
	# CHAR : 
	fa_map_location = "\uee68"
	# CHAR : 
	fa_map_location_dot = "\uee69"
	# CHAR : 
	fa_map_marker = "\uf041"
	# CHAR : 
	fa_map_o = "\uf278"
	# CHAR : 
	fa_map_pin = "\uf276"
	# CHAR : 
	fa_map_signs = "\uf277"
	# CHAR : 
	fa_markdown = "\ueeab"
	# CHAR : 
	fa_marker = "\uee6a"
	# CHAR : 
	fa_mars = "\uf222"
	# CHAR : 
	fa_mars_double = "\uf227"
	# CHAR : 
	fa_mars_stroke = "\uf229"
	# CHAR : 
	fa_mars_stroke_h = "\uf22b"
	# CHAR : 
	fa_mars_stroke_right = "\uf22b"
	# CHAR : 
	fa_mars_stroke_up = "\uf22a"
	# CHAR : 
	fa_mars_stroke_v = "\uf22a"
	# CHAR : 
	fa_martini_glass = "\uee44"
	# CHAR : 
	fa_martini_glass_citrus = "\uee2a"
	# CHAR : 
	fa_martini_glass_empty = "\uf000"
	# CHAR : 
	fa_mask = "\uef07"
	# CHAR : 
	fa_masks_theater = "\ueeb6"
	# CHAR : 
	fa_mastodon = "\uedc0"
	# CHAR : 
	fa_maxcdn = "\uf136"
	# CHAR : 
	fa_maximize = "\uf06f"
	# CHAR : 
	fa_mdb = "\uefb9"
	# CHAR : 
	fa_meanpath = "\uf20c"
	# CHAR : 
	fa_medal = "\uee6b"
	# CHAR : 
	fa_medapps = "\ued01"
	# CHAR : 
	fa_medium = "\uf23a"
	# CHAR : 
	fa_medkit = "\uf0fa"
	# CHAR : 
	fa_medrt = "\ued02"
	# CHAR : 
	fa_meetup = "\uf2e0"
	# CHAR : 
	fa_megaport = "\uee6c"
	# CHAR : 
	fa_meh_o = "\uf11a"
	# CHAR : 
	fa_memory = "\uefc5"
	# CHAR : 
	fa_mendeley = "\uef57"
	# CHAR : 
	fa_menorah = "\ueed2"
	# CHAR : 
	fa_mercury = "\uf223"
	# CHAR : 
	fa_message = "\uf27a"
	# CHAR : 
	fa_meteor = "\uef23"
	# CHAR : 
	fa_microchip = "\uf2db"
	# CHAR : 
	fa_microphone = "\uf130"
	# CHAR : 
	fa_microphone_lines = "\ued03"
	# CHAR : 
	fa_microphone_lines_slash = "\uefc6"
	# CHAR : 
	fa_microphone_slash = "\uf131"
	# CHAR : 
	fa_microscope = "\ueeac"
	# CHAR : 
	fa_microsoft = "\ued04"
	# CHAR : 
	fa_minimize = "\uef3e"
	# CHAR : 
	fa_minus = "\uf068"
	# CHAR : 
	fa_minus_circle = "\uf056"
	# CHAR : 
	fa_minus_square = "\uf146"
	# CHAR : 
	fa_minus_square_o = "\uf147"
	# CHAR : 
	fa_mitten = "\uef58"
	# CHAR : 
	fa_mix = "\ued05"
	# CHAR : 
	fa_mixcloud = "\uf289"
	# CHAR : 
	fa_mizuni = "\ued06"
	# CHAR : 
	fa_mobile = "\ued08"
	# CHAR : 
	fa_mobile_button = "\ued07"
	# CHAR : 
	fa_mobile_phone = "\uf10b"
	# CHAR : 
	fa_mobile_screen = "\ued09"
	# CHAR : 
	fa_mobile_screen_button = "\uf10b"
	# CHAR : 
	fa_modx = "\uf285"
	# CHAR : 
	fa_monero = "\ued0a"
	# CHAR : 
	fa_money = "\uf0d6"
	# CHAR : 
	fa_money_bill = "\uf0d6"
	# CHAR : 
	fa_money_bill_1 = "\ued0b"
	# CHAR : 
	fa_money_bill_1_wave = "\uefc8"
	# CHAR : 
	fa_money_bill_wave = "\uefc7"
	# CHAR : 
	fa_money_check = "\uefc9"
	# CHAR : 
	fa_money_check_dollar = "\uefca"
	# CHAR : 
	fa_monument = "\uee6f"
	# CHAR : 
	fa_moon = "\uf186"
	# CHAR : 
	fa_moon_o = "\uf186"
	# CHAR : 
	fa_mortar_board = "\uf19d"
	# CHAR : 
	fa_mortar_pestle = "\uee70"
	# CHAR : 
	fa_mosque = "\ueed3"
	# CHAR : 
	fa_motorcycle = "\uf21c"
	# CHAR : 
	fa_mountain = "\uef08"
	# CHAR : 
	fa_mouse_pointer = "\uf245"
	# CHAR : 
	fa_mug_hot = "\uef59"
	# CHAR : 
	fa_mug_saucer = "\uf0f4"
	# CHAR : 
	fa_music = "\uf001"
	# CHAR : 
	fa_napster = "\ued0c"
	# CHAR : 
	fa_navicon = "\uf0c9"
	# CHAR : 
	fa_neos = "\ueead"
	# CHAR : 
	fa_network_wired = "\uef09"
	# CHAR : 
	fa_neuter = "\uf22c"
	# CHAR : 
	fa_newspaper = "\uf1ea"
	# CHAR : 
	fa_newspaper_o = "\uf1ea"
	# CHAR : 
	fa_nimblr = "\uee71"
	# CHAR : 
	fa_node = "\ued44"
	# CHAR : 
	fa_node_js = "\ued0d"
	# CHAR : 
	fa_not_equal = "\uefcb"
	# CHAR : 
	fa_note_sticky = "\uf249"
	# CHAR : 
	fa_notes_medical = "\ued85"
	# CHAR : 
	fa_npm = "\ued0e"
	# CHAR : 
	fa_ns8 = "\ued0f"
	# CHAR : 
	fa_nutritionix = "\ued10"
	# CHAR : 
	fa_object_group = "\uf247"
	# CHAR : 
	fa_object_ungroup = "\uf248"
	# CHAR : 
	fa_odnoklassniki = "\uf263"
	# CHAR : 
	fa_odnoklassniki_square = "\uf264"
	# CHAR : 
	fa_oil_can = "\ueeae"
	# CHAR : 
	fa_ok_sign = "\uf058"
	# CHAR : 
	fa_old_republic = "\uedda"
	# CHAR : 
	fa_om = "\ueed4"
	# CHAR : 
	fa_opencart = "\uf23d"
	# CHAR : 
	fa_openid = "\uf19b"
	# CHAR : 
	fa_opera = "\uf26a"
	# CHAR : 
	fa_optin_monster = "\uf23c"
	# CHAR : 
	fa_orcid = "\uefbb"
	# CHAR : 
	fa_osi = "\ued45"
	# CHAR : 
	fa_otter = "\uef0a"
	# CHAR : 
	fa_outdent = "\uf03b"
	# CHAR : 
	fa_page4 = "\ued11"
	# CHAR : 
	fa_pagelines = "\uf18c"
	# CHAR : 
	fa_pager = "\uef8a"
	# CHAR : 
	fa_paint_brush = "\uf1fc"
	# CHAR : 
	fa_paint_roller = "\uee72"
	# CHAR : 
	fa_paintbrush = "\uf1fc"
	# CHAR : 
	fa_palette = "\uefcc"
	# CHAR : 
	fa_palfed = "\ued12"
	# CHAR : 
	fa_pallet = "\ued86"
	# CHAR : 
	fa_paper_plane = "\uf1d8"
	# CHAR : 
	fa_paper_plane_o = "\uf1d9"
	# CHAR : 
	fa_paperclip = "\uf0c6"
	# CHAR : 
	fa_parachute_box = "\ueda1"
	# CHAR : 
	fa_paragraph = "\uf1dd"
	# CHAR : 
	fa_passport = "\uee73"
	# CHAR : 
	fa_paste = "\uf0ea"
	# CHAR : 
	fa_patreon = "\ued13"
	# CHAR : 
	fa_pause = "\uf04c"
	# CHAR : 
	fa_pause_circle = "\uf28b"
	# CHAR : 
	fa_pause_circle_o = "\uf28c"
	# CHAR : 
	fa_paw = "\uf1b0"
	# CHAR : 
	fa_paypal = "\uf1ed"
	# CHAR : 
	fa_peace = "\ueed6"
	# CHAR : 
	fa_pen = "\uf01f"
	# CHAR : 
	fa_pen_clip = "\uf020"
	# CHAR : 
	fa_pen_fancy = "\uee74"
	# CHAR : 
	fa_pen_nib = "\uee75"
	# CHAR : 
	fa_pen_ruler = "\uee76"
	# CHAR : 
	fa_pen_to_square = "\uf044"
	# CHAR : 
	fa_pencil = "\uf040"
	# CHAR : 
	fa_pencil_square = "\uf14b"
	# CHAR : 
	fa_pencil_square_o = "\uf044"
	# CHAR : 
	fa_people_carry_box = "\ueda2"
	# CHAR : 
	fa_pepper_hot = "\uef8b"
	# CHAR : 
	fa_percent = "\uf295"
	# CHAR : 
	fa_periscope = "\ued14"
	# CHAR : 
	fa_person = "\uf183"
	# CHAR : 
	fa_person_biking = "\uefa2"
	# CHAR : 
	fa_person_booth = "\uef24"
	# CHAR : 
	fa_person_digging = "\uefa6"
	# CHAR : 
	fa_person_dots_from_line = "\ued7c"
	# CHAR : 
	fa_person_dress = "\uf182"
	# CHAR : 
	fa_person_hiking = "\uef02"
	# CHAR : 
	fa_person_praying = "\ueeda"
	# CHAR : 
	fa_person_running = "\uef0c"
	# CHAR : 
	fa_person_skating = "\uef63"
	# CHAR : 
	fa_person_skiing = "\uef65"
	# CHAR : 
	fa_person_skiing_nordic = "\uef66"
	# CHAR : 
	fa_person_snowboarding = "\uef69"
	# CHAR : 
	fa_person_swimming = "\uee8b"
	# CHAR : 
	fa_person_walking = "\uee1d"
	# CHAR : 
	fa_person_walking_with_cane = "\uf29d"
	# CHAR : 
	fa_phabricator = "\ued15"
	# CHAR : 
	fa_phoenix_framework = "\ued16"
	# CHAR : 
	fa_phoenix_squadron = "\ueddb"
	# CHAR : 
	fa_phone = "\uf095"
	# CHAR : 
	fa_phone_flip = "\uefa9"
	# CHAR : 
	fa_phone_slash = "\ued17"
	# CHAR : 
	fa_phone_square = "\uf098"
	# CHAR : 
	fa_phone_volume = "\uf2a0"
	# CHAR : 
	fa_photo = "\uf03e"
	# CHAR : 
	fa_photo_film = "\uefab"
	# CHAR : 
	fa_php = "\ued6d"
	# CHAR : 
	fa_picture_o = "\uf03e"
	# CHAR : 
	fa_pie_chart = "\uf200"
	# CHAR : 
	fa_pied_piper = "\uf2ae"
	# CHAR : 
	fa_pied_piper_alt = "\uf1a8"
	# CHAR : 
	fa_pied_piper_hat = "\uedb0"
	# CHAR : 
	fa_pied_piper_pp = "\uf1a7"
	# CHAR : 
	fa_piggy_bank = "\ueda3"
	# CHAR : 
	fa_pills = "\ued87"
	# CHAR : 
	fa_pinterest = "\uf0d2"
	# CHAR : 
	fa_pinterest_p = "\uf231"
	# CHAR : 
	fa_pinterest_square = "\uf0d3"
	# CHAR : 
	fa_pizza_slice = "\uef8c"
	# CHAR : 
	fa_place_of_worship = "\ueed7"
	# CHAR : 
	fa_plane = "\uf072"
	# CHAR : 
	fa_plane_arrival = "\uee77"
	# CHAR : 
	fa_plane_departure = "\uee78"
	# CHAR : 
	fa_play = "\uf04b"
	# CHAR : 
	fa_play_circle = "\uf144"
	# CHAR : 
	fa_play_circle_o = "\uf01d"
	# CHAR : 
	fa_playstation = "\ued18"
	# CHAR : 
	fa_plug = "\uf1e6"
	# CHAR : 
	fa_plus = "\uf067"
	# CHAR : 
	fa_plus_circle = "\uf055"
	# CHAR : 
	fa_plus_square = "\uf0fe"
	# CHAR : 
	fa_plus_square_o = "\uf196"
	# CHAR : 
	fa_podcast = "\uf2ce"
	# CHAR : 
	fa_poo = "\uf2fe"
	# CHAR : 
	fa_poo_storm = "\uef25"
	# CHAR : 
	fa_poop = "\ueeaf"
	# CHAR : 
	fa_power_off = "\uf011"
	# CHAR : 
	fa_prescription = "\uee79"
	# CHAR : 
	fa_prescription_bottle = "\ued88"
	# CHAR : 
	fa_prescription_bottle_medical = "\ued89"
	# CHAR : 
	fa_print = "\uf02f"
	# CHAR : 
	fa_product_hunt = "\uf288"
	# CHAR : 
	fa_pushed = "\ued1a"
	# CHAR : 
	fa_puzzle_piece = "\uf12e"
	# CHAR : 
	fa_python = "\ued1b"
	# CHAR : 
	fa_qq = "\uf1d6"
	# CHAR : 
	fa_qrcode = "\uf029"
	# CHAR : 
	fa_question = "\uf128"
	# CHAR : 
	fa_question_circle = "\uf059"
	# CHAR : 
	fa_question_circle_o = "\uf29c"
	# CHAR : 
	fa_quinscape = "\ued6f"
	# CHAR : 
	fa_quora = "\uf2c4"
	# CHAR : 
	fa_quote_left = "\uf10d"
	# CHAR : 
	fa_quote_right = "\uf10e"
	# CHAR : 
	fa_r_project = "\uedc1"
	# CHAR : 
	fa_ra = "\uf1d0"
	# CHAR : 
	fa_radiation = "\uef5a"
	# CHAR : 
	fa_radio = "\uefbc"
	# CHAR : 
	fa_rainbow = "\uef26"
	# CHAR : 
	fa_random = "\uf074"
	# CHAR : 
	fa_raspberry_pi = "\uef5c"
	# CHAR : 
	fa_ravelry = "\uf2d9"
	# CHAR : 
	fa_react = "\ued46"
	# CHAR : 
	fa_reacteurope = "\uef27"
	# CHAR : 
	fa_readme = "\ueda4"
	# CHAR : 
	fa_rebel = "\uf1d0"
	# CHAR : 
	fa_receipt = "\uee0c"
	# CHAR : 
	fa_record_vinyl = "\uefbd"
	# CHAR : 
	fa_rectangle_ad = "\ueebb"
	# CHAR : 
	fa_rectangle_list = "\uf022"
	# CHAR : 
	fa_rectangle_xmark = "\uf2d4"
	# CHAR : 
	fa_recycle = "\uf1b8"
	# CHAR : 
	fa_red_river = "\ued1c"
	# CHAR : 
	fa_reddit = "\uf1a1"
	# CHAR : 
	fa_reddit_alien = "\uf281"
	# CHAR : 
	fa_reddit_square = "\uf1a2"
	# CHAR : 
	fa_redhat = "\uef5d"
	# CHAR : 
	fa_refresh = "\uf021"
	# CHAR : 
	fa_registered = "\uf25d"
	# CHAR : 
	fa_remove = "\uf00d"
	# CHAR : 
	fa_remove_sign = "\uf057"
	# CHAR : 
	fa_renren = "\uf18b"
	# CHAR : 
	fa_reorder = "\uf0c9"
	# CHAR : 
	fa_repeat = "\uf01e"
	# CHAR : 
	fa_repeat_alt = "\uf0b6"
	# CHAR : 
	fa_reply = "\uf112"
	# CHAR : 
	fa_reply_all = "\uf122"
	# CHAR : 
	fa_replyd = "\ued1e"
	# CHAR : 
	fa_republican = "\uef28"
	# CHAR : 
	fa_researchgate = "\uedc2"
	# CHAR : 
	fa_resistance = "\uf1d0"
	# CHAR : 
	fa_resolving = "\ued1f"
	# CHAR : 
	fa_restroom = "\uef5e"
	# CHAR : 
	fa_retweet = "\uf079"
	# CHAR : 
	fa_rev = "\uee7a"
	# CHAR : 
	fa_ribbon = "\ueda5"
	# CHAR : 
	fa_right_from_bracket = "\uf2f5"
	# CHAR : 
	fa_right_left = "\uf0b5"
	# CHAR : 
	fa_right_to_bracket = "\uf2f6"
	# CHAR : 
	fa_ring = "\uef0b"
	# CHAR : 
	fa_rmb = "\uf157"
	# CHAR : 
	fa_road = "\uf018"
	# CHAR : 
	fa_robot = "\uee0d"
	# CHAR : 
	fa_rocket = "\uf135"
	# CHAR : 
	fa_rocketchat = "\ued20"
	# CHAR : 
	fa_rockrms = "\ued21"
	# CHAR : 
	fa_rotate = "\uf2f1"
	# CHAR : 
	fa_rotate_left = "\uf2ea"
	# CHAR : 
	fa_rotate_right = "\uf2f9"
	# CHAR : 
	fa_rouble = "\uf158"
	# CHAR : 
	fa_route = "\ueda6"
	# CHAR : 
	fa_rss = "\uf09e"
	# CHAR : 
	fa_rss_square = "\uf143"
	# CHAR : 
	fa_rub = "\uf158"
	# CHAR : 
	fa_ruble = "\uf158"
	# CHAR : 
	fa_ruble_sign = "\uf158"
	# CHAR : 
	fa_ruler = "\uee0e"
	# CHAR : 
	fa_ruler_combined = "\uee0f"
	# CHAR : 
	fa_ruler_horizontal = "\uee10"
	# CHAR : 
	fa_ruler_vertical = "\uee11"
	# CHAR : 
	fa_rupee = "\uf156"
	# CHAR : 
	fa_rupee_sign = "\uf156"
	# CHAR : 
	fa_s15 = "\uf2cd"
	# CHAR : 
	fa_sack_dollar = "\uef8d"
	# CHAR : 
	fa_safari = "\uf267"
	# CHAR : 
	fa_salesforce = "\uef9a"
	# CHAR : 
	fa_sass = "\ued49"
	# CHAR : 
	fa_satellite = "\uef5f"
	# CHAR : 
	fa_satellite_dish = "\uef60"
	# CHAR : 
	fa_save = "\uf0c7"
	# CHAR : 
	fa_scale_balanced = "\uf24e"
	# CHAR : 
	fa_scale_unbalanced = "\ueddf"
	# CHAR : 
	fa_scale_unbalanced_flip = "\uede0"
	# CHAR : 
	fa_schlix = "\ued22"
	# CHAR : 
	fa_school = "\uee12"
	# CHAR : 
	fa_scissors = "\uf0c4"
	# CHAR : 
	fa_screwdriver = "\uee13"
	# CHAR : 
	fa_screwdriver_wrench = "\uef70"
	# CHAR : 
	fa_scribd = "\uf28a"
	# CHAR : 
	fa_scroll = "\uef0d"
	# CHAR : 
	fa_scroll_torah = "\ueee5"
	# CHAR : 
	fa_sd_card = "\uef61"
	# CHAR : 
	fa_search = "\uf002"
	# CHAR : 
	fa_search_minus = "\uf010"
	# CHAR : 
	fa_search_plus = "\uf00e"
	# CHAR : 
	fa_searchengin = "\ued23"
	# CHAR : 
	fa_seedling = "\ueda7"
	# CHAR : 
	fa_sellcast = "\uf2da"
	# CHAR : 
	fa_sellsy = "\uf213"
	# CHAR : 
	fa_send = "\uf1d8"
	# CHAR : 
	fa_send_o = "\uf1d9"
	# CHAR : 
	fa_server = "\uf233"
	# CHAR : 
	fa_servicestack = "\ued24"
	# CHAR : 
	fa_shapes = "\ueeb0"
	# CHAR : 
	fa_share = "\uf064"
	# CHAR : 
	fa_share_alt = "\uf1e0"
	# CHAR : 
	fa_share_alt_square = "\uf1e1"
	# CHAR : 
	fa_share_from_square = "\uf14d"
	# CHAR : 
	fa_share_nodes = "\uf1e0"
	# CHAR : 
	fa_share_square = "\uf14d"
	# CHAR : 
	fa_share_square_o = "\uf045"
	# CHAR : 
	fa_shekel = "\uf20b"
	# CHAR : 
	fa_shekel_sign = "\uf20b"
	# CHAR : 
	fa_sheqel = "\uf20b"
	# CHAR : 
	fa_shield = "\uf132"
	# CHAR : 
	fa_shield_halved = "\ued25"
	# CHAR : 
	fa_ship = "\uf21a"
	# CHAR : 
	fa_shirt = "\uee1c"
	# CHAR : 
	fa_shirtsinbulk = "\uf214"
	# CHAR : 
	fa_shoe_prints = "\uee14"
	# CHAR : 
	fa_shop = "\uee18"
	# CHAR : 
	fa_shopping_bag = "\uf290"
	# CHAR : 
	fa_shopping_basket = "\uf291"
	# CHAR : 
	fa_shopping_cart = "\uf07a"
	# CHAR : 
	fa_shopware = "\uee7d"
	# CHAR : 
	fa_shower = "\uf2cc"
	# CHAR : 
	fa_shuffle = "\uf074"
	# CHAR : 
	fa_shuttle_space = "\uf197"
	# CHAR : 
	fa_sign_hanging = "\ueda8"
	# CHAR : 
	fa_sign_in = "\uf090"
	# CHAR : 
	fa_sign_language = "\uf2a7"
	# CHAR : 
	fa_sign_out = "\uf08b"
	# CHAR : 
	fa_signal = "\uf012"
	# CHAR : 
	fa_signature = "\uee7f"
	# CHAR : 
	fa_signing = "\uf2a7"
	# CHAR : 
	fa_signs_post = "\uf277"
	# CHAR : 
	fa_sim_card = "\uef62"
	# CHAR : 
	fa_simplybuilt = "\uf215"
	# CHAR : 
	fa_sistrix = "\ued26"
	# CHAR : 
	fa_sitemap = "\uf0e8"
	# CHAR : 
	fa_sith = "\ueddc"
	# CHAR : 
	fa_sketch = "\uef64"
	# CHAR : 
	fa_skull = "\uee15"
	# CHAR : 
	fa_skull_crossbones = "\uef0e"
	# CHAR : 
	fa_skyatlas = "\uf216"
	# CHAR : 
	fa_skype = "\uf17e"
	# CHAR : 
	fa_slack = "\uf198"
	# CHAR : 
	fa_slash = "\uef0f"
	# CHAR : 
	fa_sleigh = "\uef67"
	# CHAR : 
	fa_sliders = "\uf1de"
	# CHAR : 
	fa_slideshare = "\uf1e7"
	# CHAR : 
	fa_smile_o = "\uf118"
	# CHAR : 
	fa_smog = "\uef29"
	# CHAR : 
	fa_smoking = "\ued8c"
	# CHAR : 
	fa_snapchat = "\uf2ab"
	# CHAR : 
	fa_snapchat_ghost = "\uf2ac"
	# CHAR : 
	fa_snapchat_square = "\uf2ad"
	# CHAR : 
	fa_snowflake = "\uf2dc"
	# CHAR : 
	fa_snowflake_o = "\uf2dc"
	# CHAR : 
	fa_snowman = "\uef6a"
	# CHAR : 
	fa_snowplow = "\uef6b"
	# CHAR : 
	fa_soccer_ball_o = "\uf1e3"
	# CHAR : 
	fa_socks = "\ueedf"
	# CHAR : 
	fa_solar_panel = "\uee81"
	# CHAR : 
	fa_sort = "\uf0dc"
	# CHAR : 
	fa_sort_alpha_asc = "\uf15d"
	# CHAR : 
	fa_sort_alpha_desc = "\uf15e"
	# CHAR : 
	fa_sort_amount_asc = "\uf160"
	# CHAR : 
	fa_sort_amount_desc = "\uf161"
	# CHAR : 
	fa_sort_asc = "\uf0de"
	# CHAR : 
	fa_sort_desc = "\uf0dd"
	# CHAR : 
	fa_sort_down = "\uf0dd"
	# CHAR : 
	fa_sort_numeric_asc = "\uf162"
	# CHAR : 
	fa_sort_numeric_desc = "\uf163"
	# CHAR : 
	fa_sort_up = "\uf0de"
	# CHAR : 
	fa_soundcloud = "\uf1be"
	# CHAR : 
	fa_sourcetree = "\uef6c"
	# CHAR : 
	fa_spa = "\uee82"
	# CHAR : 
	fa_space_shuttle = "\uf197"
	# CHAR : 
	fa_spaghetti_monster_flying = "\ueed5"
	# CHAR : 
	fa_speakap = "\ued27"
	# CHAR : 
	fa_speaker_deck = "\uef9b"
	# CHAR : 
	fa_spell_check = "\uefb3"
	# CHAR : 
	fa_spider = "\uef10"
	# CHAR : 
	fa_spinner = "\uf110"
	# CHAR : 
	fa_splotch = "\uee83"
	# CHAR : 
	fa_spoon = "\uf1b1"
	# CHAR : 
	fa_spotify = "\uf1bc"
	# CHAR : 
	fa_spray_can = "\uee84"
	# CHAR : 
	fa_spray_can_sparkles = "\uee97"
	# CHAR : 
	fa_square = "\uf0c8"
	# CHAR : 
	fa_square_arrow_up_right = "\uf14c"
	# CHAR : 
	fa_square_behance = "\uf1b5"
	# CHAR : 
	fa_square_caret_down = "\uf150"
	# CHAR : 
	fa_square_caret_left = "\uf191"
	# CHAR : 
	fa_square_caret_right = "\uf152"
	# CHAR : 
	fa_square_caret_up = "\uf151"
	# CHAR : 
	fa_square_check = "\uf14a"
	# CHAR : 
	fa_square_dribbble = "\uf22e"
	# CHAR : 
	fa_square_envelope = "\uf199"
	# CHAR : 
	fa_square_facebook = "\uf082"
	# CHAR : 
	fa_square_font_awesome_stroke = "\uf0af"
	# CHAR : 
	fa_square_full = "\ued70"
	# CHAR : 
	fa_square_git = "\uf1d2"
	# CHAR : 
	fa_square_github = "\uf092"
	# CHAR : 
	fa_square_google_plus = "\uf0d4"
	# CHAR : 
	fa_square_h = "\uf0fd"
	# CHAR : 
	fa_square_hacker_news = "\uf2e5"
	# CHAR : 
	fa_square_js = "\uf2ef"
	# CHAR : 
	fa_square_lastfm = "\uf203"
	# CHAR : 
	fa_square_minus = "\uf146"
	# CHAR : 
	fa_square_o = "\uf096"
	# CHAR : 
	fa_square_odnoklassniki = "\uf264"
	# CHAR : 
	fa_square_parking = "\uefcd"
	# CHAR : 
	fa_square_pen = "\uf14b"
	# CHAR : 
	fa_square_phone = "\uf098"
	# CHAR : 
	fa_square_phone_flip = "\uefaa"
	# CHAR : 
	fa_square_pinterest = "\uf0d3"
	# CHAR : 
	fa_square_plus = "\uf0fe"
	# CHAR : 
	fa_square_poll_horizontal = "\ueed9"
	# CHAR : 
	fa_square_poll_vertical = "\ueed8"
	# CHAR : 
	fa_square_reddit = "\uf1a2"
	# CHAR : 
	fa_square_root_variable = "\ueee0"
	# CHAR : 
	fa_square_rss = "\uf143"
	# CHAR : 
	fa_square_share_nodes = "\uf1e1"
	# CHAR : 
	fa_square_snapchat = "\uf2ad"
	# CHAR : 
	fa_square_steam = "\uf1b7"
	# CHAR : 
	fa_square_tumblr = "\uf174"
	# CHAR : 
	fa_square_twitter = "\uf081"
	# CHAR : 
	fa_square_up_right = "\uf0b4"
	# CHAR : 
	fa_square_viadeo = "\uf2aa"
	# CHAR : 
	fa_square_vimeo = "\uf194"
	# CHAR : 
	fa_square_whatsapp = "\ued3b"
	# CHAR : 
	fa_square_xing = "\uf169"
	# CHAR : 
	fa_square_xmark = "\uf2d3"
	# CHAR : 
	fa_square_youtube = "\uf166"
	# CHAR : 
	fa_squarespace = "\uee85"
	# CHAR : 
	fa_stack_exchange = "\uf18d"
	# CHAR : 
	fa_stack_overflow = "\uf16c"
	# CHAR : 
	fa_stackpath = "\uefa1"
	# CHAR : 
	fa_stamp = "\uee86"
	# CHAR : 
	fa_star = "\uf005"
	# CHAR : 
	fa_star_and_crescent = "\ueee1"
	# CHAR : 
	fa_star_half = "\uf089"
	# CHAR : 
	fa_star_half_empty = "\uf123"
	# CHAR : 
	fa_star_half_full = "\uf123"
	# CHAR : 
	fa_star_half_o = "\uf123"
	# CHAR : 
	fa_star_half_stroke = "\uee87"
	# CHAR : 
	fa_star_o = "\uf006"
	# CHAR : 
	fa_star_of_david = "\ueee2"
	# CHAR : 
	fa_star_of_life = "\ueeb1"
	# CHAR : 
	fa_staylinked = "\ued28"
	# CHAR : 
	fa_steam = "\uf1b6"
	# CHAR : 
	fa_steam_square = "\uf1b7"
	# CHAR : 
	fa_steam_symbol = "\ued29"
	# CHAR : 
	fa_step_backward = "\uf048"
	# CHAR : 
	fa_step_forward = "\uf051"
	# CHAR : 
	fa_sterling_sign = "\uf154"
	# CHAR : 
	fa_stethoscope = "\uf0f1"
	# CHAR : 
	fa_sticker_mule = "\ued2a"
	# CHAR : 
	fa_sticky_note = "\uf249"
	# CHAR : 
	fa_sticky_note_o = "\uf24a"
	# CHAR : 
	fa_stop = "\uf04d"
	# CHAR : 
	fa_stop_circle = "\uf28d"
	# CHAR : 
	fa_stop_circle_o = "\uf28e"
	# CHAR : 
	fa_stopwatch = "\uf2f2"
	# CHAR : 
	fa_store = "\uee17"
	# CHAR : 
	fa_strava = "\ued52"
	# CHAR : 
	fa_street_view = "\uf21d"
	# CHAR : 
	fa_strikethrough = "\uf0cc"
	# CHAR : 
	fa_stripe = "\ued53"
	# CHAR : 
	fa_stripe_s = "\ued54"
	# CHAR : 
	fa_stroopwafel = "\uee1a"
	# CHAR : 
	fa_studiovinari = "\ued2b"
	# CHAR : 
	fa_stumbleupon = "\uf1a4"
	# CHAR : 
	fa_stumbleupon_circle = "\uf1a3"
	# CHAR : 
	fa_subscript = "\uf12c"
	# CHAR : 
	fa_subway = "\uf239"
	# CHAR : 
	fa_suitcase = "\uf0f2"
	# CHAR : 
	fa_suitcase_medical = "\uf0fa"
	# CHAR : 
	fa_suitcase_rolling = "\uee88"
	# CHAR : 
	fa_sun = "\uf185"
	# CHAR : 
	fa_sun_o = "\uf185"
	# CHAR : 
	fa_superpowers = "\uf2dd"
	# CHAR : 
	fa_superscript = "\uf12b"
	# CHAR : 
	fa_supple = "\ued2c"
	# CHAR : 
	fa_support = "\uf1cd"
	# CHAR : 
	fa_suse = "\uef6d"
	# CHAR : 
	fa_swatchbook = "\uee8a"
	# CHAR : 
	fa_swift = "\uefbe"
	# CHAR : 
	fa_symfony = "\uef9c"
	# CHAR : 
	fa_synagogue = "\ueee3"
	# CHAR : 
	fa_syringe = "\ued8d"
	# CHAR : 
	fa_table = "\uf0ce"
	# CHAR : 
	fa_table_cells = "\uf00a"
	# CHAR : 
	fa_table_cells_large = "\uf009"
	# CHAR : 
	fa_table_columns = "\uf0db"
	# CHAR : 
	fa_table_list = "\uf00b"
	# CHAR : 
	fa_table_tennis_paddle_ball = "\ued71"
	# CHAR : 
	fa_tablet = "\ued2e"
	# CHAR : 
	fa_tablet_button = "\ued2d"
	# CHAR : 
	fa_tablet_screen_button = "\uf10a"
	# CHAR : 
	fa_tablets = "\ued8e"
	# CHAR : 
	fa_tachograph_digital = "\uee2f"
	# CHAR : 
	fa_tachometer = "\uf0e4"
	# CHAR : 
	fa_tag = "\uf02b"
	# CHAR : 
	fa_tags = "\uf02c"
	# CHAR : 
	fa_tape = "\uedaa"
	# CHAR : 
	fa_tasks = "\uf0ae"
	# CHAR : 
	fa_taxi = "\uf1ba"
	# CHAR : 
	fa_teamspeak = "\uedc3"
	# CHAR : 
	fa_teeth = "\ueeb4"
	# CHAR : 
	fa_teeth_open = "\ueeb5"
	# CHAR : 
	fa_telegram = "\uf2c6"
	# CHAR : 
	fa_television = "\uf26c"
	# CHAR : 
	fa_temperature_empty = "\uf2cb"
	# CHAR : 
	fa_temperature_full = "\uf2c7"
	# CHAR : 
	fa_temperature_half = "\uf2c9"
	# CHAR : 
	fa_temperature_high = "\uef2a"
	# CHAR : 
	fa_temperature_low = "\uef2b"
	# CHAR : 
	fa_temperature_quarter = "\uf2ca"
	# CHAR : 
	fa_temperature_three_quarters = "\uf2c8"
	# CHAR : 
	fa_tencent_weibo = "\uf1d5"
	# CHAR : 
	fa_tenge_sign = "\uef6e"
	# CHAR : 
	fa_terminal = "\uf120"
	# CHAR : 
	fa_text_height = "\uf034"
	# CHAR : 
	fa_text_slash = "\uefac"
	# CHAR : 
	fa_text_width = "\uf035"
	# CHAR : 
	fa_th = "\uf00a"
	# CHAR : 
	fa_th_large = "\uf009"
	# CHAR : 
	fa_th_list = "\uf00b"
	# CHAR : 
	fa_the_red_yeti = "\ueee4"
	# CHAR : 
	fa_themeco = "\uee8d"
	# CHAR : 
	fa_themeisle = "\uf2b2"
	# CHAR : 
	fa_thermometer = "\uf2c7"
	# CHAR : 
	fa_thermometer_0 = "\uf2cb"
	# CHAR : 
	fa_thermometer_1 = "\uf2ca"
	# CHAR : 
	fa_thermometer_2 = "\uf2c9"
	# CHAR : 
	fa_thermometer_3 = "\uf2c8"
	# CHAR : 
	fa_thermometer_4 = "\uf2c7"
	# CHAR : 
	fa_thermometer_alt = "\ued8f"
	# CHAR : 
	fa_thermometer_empty = "\uf2cb"
	# CHAR : 
	fa_thermometer_full = "\uf2c7"
	# CHAR : 
	fa_thermometer_half = "\uf2c9"
	# CHAR : 
	fa_thermometer_quarter = "\uf2ca"
	# CHAR : 
	fa_thermometer_three_quarters = "\uf2c8"
	# CHAR : 
	fa_think_peaks = "\uef19"
	# CHAR : 
	fa_thumb_tack = "\uf08d"
	# CHAR : 
	fa_thumbs_down = "\uf165"
	# CHAR : 
	fa_thumbs_o_down = "\uf088"
	# CHAR : 
	fa_thumbs_o_up = "\uf087"
	# CHAR : 
	fa_thumbs_up = "\uf164"
	# CHAR : 
	fa_thumbtack = "\uf08d"
	# CHAR : 
	fa_ticket = "\uf145"
	# CHAR : 
	fa_ticket_simple = "\ued30"
	# CHAR : 
	fa_times = "\uf00d"
	# CHAR : 
	fa_times_circle = "\uf057"
	# CHAR : 
	fa_times_circle_o = "\uf05c"
	# CHAR : 
	fa_times_rectangle = "\uf2d3"
	# CHAR : 
	fa_times_rectangle_o = "\uf2d4"
	# CHAR : 
	fa_tint = "\uf043"
	# CHAR : 
	fa_toggle_down = "\uf150"
	# CHAR : 
	fa_toggle_left = "\uf191"
	# CHAR : 
	fa_toggle_off = "\uf204"
	# CHAR : 
	fa_toggle_on = "\uf205"
	# CHAR : 
	fa_toggle_right = "\uf152"
	# CHAR : 
	fa_toggle_up = "\uf151"
	# CHAR : 
	fa_toilet = "\uef6f"
	# CHAR : 
	fa_toilet_paper = "\uef11"
	# CHAR : 
	fa_toolbox = "\uee1b"
	# CHAR : 
	fa_tooth = "\uee90"
	# CHAR : 
	fa_torii_gate = "\ueee6"
	# CHAR : 
	fa_tornado = "\uef2d"
	# CHAR : 
	fa_tower_broadcast = "\uede3"
	# CHAR : 
	fa_tractor = "\uef12"
	# CHAR : 
	fa_trade_federation = "\ueddd"
	# CHAR : 
	fa_trademark = "\uf25c"
	# CHAR : 
	fa_traffic_light = "\ueeb7"
	# CHAR : 
	fa_train = "\uf238"
	# CHAR : 
	fa_train_subway = "\uf239"
	# CHAR : 
	fa_transgender = "\uf224"
	# CHAR : 
	fa_transgender_alt = "\uf225"
	# CHAR : 
	fa_trash = "\uf1f8"
	# CHAR : 
	fa_trash_arrow_up = "\uef90"
	# CHAR : 
	fa_trash_can = "\uf014"
	# CHAR : 
	fa_trash_can_arrow_up = "\uef91"
	# CHAR : 
	fa_trash_o = "\uf014"
	# CHAR : 
	fa_tree = "\uf1bb"
	# CHAR : 
	fa_trello = "\uf181"
	# CHAR : 
	fa_triangle_exclamation = "\uf071"
	# CHAR : 
	fa_tripadvisor = "\uf262"
	# CHAR : 
	fa_trophy = "\uf091"
	# CHAR : 
	fa_truck = "\uf0d1"
	# CHAR : 
	fa_truck_fast = "\ued8b"
	# CHAR : 
	fa_truck_medical = "\uf0f9"
	# CHAR : 
	fa_truck_monster = "\ueeb8"
	# CHAR : 
	fa_truck_moving = "\uedac"
	# CHAR : 
	fa_truck_pickup = "\ueeb9"
	# CHAR : 
	fa_truck_ramp_box = "\uedab"
	# CHAR : 
	fa_try = "\uf195"
	# CHAR : 
	fa_tty = "\uf1e4"
	# CHAR : 
	fa_tumblr = "\uf173"
	# CHAR : 
	fa_tumblr_square = "\uf174"
	# CHAR : 
	fa_turkish_lira = "\uf195"
	# CHAR : 
	fa_turn_down = "\uf2f8"
	# CHAR : 
	fa_turn_up = "\uf2fa"
	# CHAR : 
	fa_tv = "\uf26c"
	# CHAR : 
	fa_twitch = "\uf1e8"
	# CHAR : 
	fa_twitter = "\uf099"
	# CHAR : 
	fa_twitter_square = "\uf081"
	# CHAR : 
	fa_typo3 = "\ued55"
	# CHAR : 
	fa_uber = "\ued31"
	# CHAR : 
	fa_ubuntu = "\uef72"
	# CHAR : 
	fa_uikit = "\ued32"
	# CHAR : 
	fa_umbraco = "\uefbf"
	# CHAR : 
	fa_umbrella = "\uf0e9"
	# CHAR : 
	fa_umbrella_beach = "\uee91"
	# CHAR : 
	fa_underline = "\uf0cd"
	# CHAR : 
	fa_undo = "\uf0e2"
	# CHAR : 
	fa_uniregistry = "\ued33"
	# CHAR : 
	fa_universal_access = "\uf29a"
	# CHAR : 
	fa_university = "\uf19c"
	# CHAR : 
	fa_unlink = "\uf127"
	# CHAR : 
	fa_unlock = "\uf09c"
	# CHAR : 
	fa_unlock_alt = "\uf13e"
	# CHAR : 
	fa_unlock_keyhole = "\uf13e"
	# CHAR : 
	fa_unsorted = "\uf0dc"
	# CHAR : 
	fa_untappd = "\ued34"
	# CHAR : 
	fa_up_down = "\uf09f"
	# CHAR : 
	fa_up_down_left_right = "\uf0b2"
	# CHAR : 
	fa_up_right_and_down_left_from_center = "\ued4f"
	# CHAR : 
	fa_up_right_from_square = "\uf0b3"
	# CHAR : 
	fa_upload = "\uf093"
	# CHAR : 
	fa_ups = "\uef73"
	# CHAR : 
	fa_usb = "\uf287"
	# CHAR : 
	fa_usd = "\uf155"
	# CHAR : 
	fa_user = "\uf007"
	# CHAR : 
	fa_user_astronaut = "\uedc5"
	# CHAR : 
	fa_user_check = "\uedc6"
	# CHAR : 
	fa_user_circle = "\uf2bd"
	# CHAR : 
	fa_user_circle_o = "\uf2be"
	# CHAR : 
	fa_user_clock = "\uedc7"
	# CHAR : 
	fa_user_doctor = "\uf0f0"
	# CHAR : 
	fa_user_gear = "\uedc8"
	# CHAR : 
	fa_user_graduate = "\uedcb"
	# CHAR : 
	fa_user_group = "\uedca"
	# CHAR : 
	fa_user_injured = "\uef13"
	# CHAR : 
	fa_user_large = "\ued35"
	# CHAR : 
	fa_user_large_slash = "\uedc4"
	# CHAR : 
	fa_user_lock = "\uedcc"
	# CHAR : 
	fa_user_md = "\uf0f0"
	# CHAR : 
	fa_user_minus = "\uedcd"
	# CHAR : 
	fa_user_ninja = "\uedce"
	# CHAR : 
	fa_user_nurse = "\uef92"
	# CHAR : 
	fa_user_o = "\uf2c0"
	# CHAR : 
	fa_user_pen = "\uedc9"
	# CHAR : 
	fa_user_plus = "\uf234"
	# CHAR : 
	fa_user_secret = "\uf21b"
	# CHAR : 
	fa_user_shield = "\uedcf"
	# CHAR : 
	fa_user_slash = "\uedd0"
	# CHAR : 
	fa_user_tag = "\uedd1"
	# CHAR : 
	fa_user_tie = "\uedd2"
	# CHAR : 
	fa_user_times = "\uf235"
	# CHAR : 
	fa_user_xmark = "\uf235"
	# CHAR : 
	fa_users = "\uf0c0"
	# CHAR : 
	fa_users_gear = "\uedd3"
	# CHAR : 
	fa_usps = "\uef74"
	# CHAR : 
	fa_ussunnah = "\ued36"
	# CHAR : 
	fa_utensils = "\uf0f5"
	# CHAR : 
	fa_vaadin = "\ued37"
	# CHAR : 
	fa_van_shuttle = "\uee7e"
	# CHAR : 
	fa_vcard = "\uf2bb"
	# CHAR : 
	fa_vcard_o = "\uf2bc"
	# CHAR : 
	fa_vector_square = "\uee92"
	# CHAR : 
	fa_venus = "\uf221"
	# CHAR : 
	fa_venus_double = "\uf226"
	# CHAR : 
	fa_venus_mars = "\uf228"
	# CHAR : 
	fa_viacoin = "\uf237"
	# CHAR : 
	fa_viadeo = "\uf2a9"
	# CHAR : 
	fa_viadeo_square = "\uf2aa"
	# CHAR : 
	fa_vial = "\ued90"
	# CHAR : 
	fa_vials = "\ued91"
	# CHAR : 
	fa_viber = "\ued38"
	# CHAR : 
	fa_video = "\uf03d"
	# CHAR : 
	fa_video_camera = "\uf03d"
	# CHAR : 
	fa_video_slash = "\uedad"
	# CHAR : 
	fa_vihara = "\ueee7"
	# CHAR : 
	fa_vimeo = "\ued39"
	# CHAR : 
	fa_vimeo_square = "\uf194"
	# CHAR : 
	fa_vimeo_v = "\uf27d"
	# CHAR : 
	fa_vine = "\uf1ca"
	# CHAR : 
	fa_vk = "\uf189"
	# CHAR : 
	fa_vnv = "\ued3a"
	# CHAR : 
	fa_voicemail = "\uefb4"
	# CHAR : 
	fa_volcano = "\uef2e"
	# CHAR : 
	fa_volleyball = "\ued72"
	# CHAR : 
	fa_volume_control_phone = "\uf2a0"
	# CHAR : 
	fa_volume_down = "\uf027"
	# CHAR : 
	fa_volume_high = "\uf028"
	# CHAR : 
	fa_volume_low = "\uf027"
	# CHAR : 
	fa_volume_off = "\uf026"
	# CHAR : 
	fa_volume_up = "\uf028"
	# CHAR : 
	fa_volume_xmark = "\ueee8"
	# CHAR : 
	fa_vr_cardboard = "\uef14"
	# CHAR : 
	fa_vuejs = "\ued4a"
	# CHAR : 
	fa_walkie_talkie = "\uefc0"
	# CHAR : 
	fa_wallet = "\uee1e"
	# CHAR : 
	fa_wand_magic = "\uf0d0"
	# CHAR : 
	fa_wand_sparkles = "\uef15"
	# CHAR : 
	fa_warehouse = "\ued92"
	# CHAR : 
	fa_warning = "\uf071"
	# CHAR : 
	fa_water = "\uef30"
	# CHAR : 
	fa_water_ladder = "\uee8c"
	# CHAR : 
	fa_wave_square = "\uef9d"
	# CHAR : 
	fa_waze = "\uef9e"
	# CHAR : 
	fa_wechat = "\uf1d7"
	# CHAR : 
	fa_weebly = "\uee93"
	# CHAR : 
	fa_weibo = "\uf18a"
	# CHAR : 
	fa_weight_hanging = "\uee94"
	# CHAR : 
	fa_weight_scale = "\ued93"
	# CHAR : 
	fa_weixin = "\uf1d7"
	# CHAR : 
	fa_whatsapp = "\uf232"
	# CHAR : 
	fa_wheelchair = "\uf193"
	# CHAR : 
	fa_wheelchair_alt = "\uf29b"
	# CHAR : 
	fa_whiskey_glass = "\uef4a"
	# CHAR : 
	fa_whmcs = "\ued3c"
	# CHAR : 
	fa_wifi = "\uf1eb"
	# CHAR : 
	fa_wikipedia_w = "\uf266"
	# CHAR : 
	fa_wind = "\uef16"
	# CHAR : 
	fa_window_close = "\uf2d3"
	# CHAR : 
	fa_window_close_o = "\uf2d4"
	# CHAR : 
	fa_window_maximize = "\uf2d0"
	# CHAR : 
	fa_window_minimize = "\uf2d1"
	# CHAR : 
	fa_window_restore = "\uf2d2"
	# CHAR : 
	fa_windows = "\uf17a"
	# CHAR : 
	fa_wine_bottle = "\uef17"
	# CHAR : 
	fa_wine_glass = "\uedae"
	# CHAR : 
	fa_wine_glass_empty = "\uee95"
	# CHAR : 
	fa_wix = "\uee96"
	# CHAR : 
	fa_wizards_of_the_coast = "\uef18"
	# CHAR : 
	fa_wolf_pack_battalion = "\uedde"
	# CHAR : 
	fa_won = "\uf159"
	# CHAR : 
	fa_won_sign = "\uf159"
	# CHAR : 
	fa_wordpress = "\uf19a"
	# CHAR : 
	fa_wordpress_simple = "\ued3d"
	# CHAR : 
	fa_wpbeginner = "\uf297"
	# CHAR : 
	fa_wpexplorer = "\uf2de"
	# CHAR : 
	fa_wpforms = "\uf298"
	# CHAR : 
	fa_wpressr = "\ued1d"
	# CHAR : 
	fa_wrench = "\uf0ad"
	# CHAR : 
	fa_x_ray = "\ued94"
	# CHAR : 
	fa_xbox = "\ued3e"
	# CHAR : 
	fa_xing = "\uf168"
	# CHAR : 
	fa_xing_square = "\uf169"
	# CHAR : 
	fa_xmark = "\uf00d"
	# CHAR : 
	fa_y_combinator = "\uf23b"
	# CHAR : 
	fa_y_combinator_square = "\uf1d4"
	# CHAR : 
	fa_yahoo = "\uf19e"
	# CHAR : 
	fa_yammer = "\uef9f"
	# CHAR : 
	fa_yandex = "\ued3f"
	# CHAR : 
	fa_yandex_international = "\ued40"
	# CHAR : 
	fa_yarn = "\uef75"
	# CHAR : 
	fa_yc = "\uf23b"
	# CHAR : 
	fa_yc_square = "\uf1d4"
	# CHAR : 
	fa_yelp = "\uf1e9"
	# CHAR : 
	fa_yen = "\uf157"
	# CHAR : 
	fa_yen_sign = "\uf157"
	# CHAR : 
	fa_yin_yang = "\ueee9"
	# CHAR : 
	fa_yoast = "\uf2b1"
	# CHAR : 
	fa_youtube = "\uf16a"
	# CHAR : 
	fa_youtube_play = "\uf16a"
	# CHAR : 
	fa_youtube_square = "\uf166"
	# CHAR : 
	fa_zhihu = "\ueeba"


# This File GEN using nerdicons_gen.py

class Fae:

	# CHAR : 
	fae_apple_fruit = "\ue29e"
	# CHAR : 
	fae_atom = "\ue27f"
	# CHAR : 
	fae_bacteria = "\ue280"
	# CHAR : 
	fae_banana = "\ue281"
	# CHAR : 
	fae_bath = "\ue282"
	# CHAR : 
	fae_bed = "\ue283"
	# CHAR : 
	fae_benzene = "\ue284"
	# CHAR : 
	fae_bigger = "\ue285"
	# CHAR : 
	fae_biohazard = "\ue286"
	# CHAR : 
	fae_blogger_circle = "\ue287"
	# CHAR : 
	fae_blogger_square = "\ue288"
	# CHAR : 
	fae_bones = "\ue289"
	# CHAR : 
	fae_book_open = "\ue28a"
	# CHAR : 
	fae_book_open_o = "\ue28b"
	# CHAR : 
	fae_brain = "\ue28c"
	# CHAR : 
	fae_bread = "\ue28d"
	# CHAR : 
	fae_butterfly = "\ue28e"
	# CHAR : 
	fae_carot = "\ue28f"
	# CHAR : 
	fae_cc_by = "\ue290"
	# CHAR : 
	fae_cc_cc = "\ue291"
	# CHAR : 
	fae_cc_nc = "\ue292"
	# CHAR : 
	fae_cc_nc_eu = "\ue293"
	# CHAR : 
	fae_cc_nc_jp = "\ue294"
	# CHAR : 
	fae_cc_nd = "\ue295"
	# CHAR : 
	fae_cc_remix = "\ue296"
	# CHAR : 
	fae_cc_sa = "\ue297"
	# CHAR : 
	fae_cc_share = "\ue298"
	# CHAR : 
	fae_cc_zero = "\ue299"
	# CHAR : 
	fae_checklist_o = "\ue29a"
	# CHAR : 
	fae_cheese = "\ue264"
	# CHAR : 
	fae_cherry = "\ue29b"
	# CHAR : 
	fae_chess_bishop = "\ue29c"
	# CHAR : 
	fae_chess_horse = "\ue25f"
	# CHAR : 
	fae_chess_king = "\ue260"
	# CHAR : 
	fae_chess_pawn = "\ue261"
	# CHAR : 
	fae_chess_queen = "\ue262"
	# CHAR : 
	fae_chess_tower = "\ue263"
	# CHAR : 
	fae_chicken_thigh = "\ue29f"
	# CHAR : 
	fae_chilli = "\ue265"
	# CHAR : 
	fae_chip = "\ue266"
	# CHAR : 
	fae_cicling = "\ue267"
	# CHAR : 
	fae_cloud = "\ue268"
	# CHAR : 
	fae_cockroach = "\ue269"
	# CHAR : 
	fae_coffe_beans = "\ue26a"
	# CHAR : 
	fae_coins = "\ue26b"
	# CHAR : 
	fae_comb = "\ue26c"
	# CHAR : 
	fae_comet = "\ue26d"
	# CHAR : 
	fae_crown = "\ue26e"
	# CHAR : 
	fae_cup_coffe = "\ue26f"
	# CHAR : 
	fae_dice = "\ue270"
	# CHAR : 
	fae_disco = "\ue271"
	# CHAR : 
	fae_dna = "\ue272"
	# CHAR : 
	fae_donut = "\ue273"
	# CHAR : 
	fae_dress = "\ue274"
	# CHAR : 
	fae_drop = "\ue275"
	# CHAR : 
	fae_ello = "\ue276"
	# CHAR : 
	fae_envelope_open = "\ue277"
	# CHAR : 
	fae_envelope_open_o = "\ue278"
	# CHAR : 
	fae_equal = "\ue279"
	# CHAR : 
	fae_equal_bigger = "\ue27a"
	# CHAR : 
	fae_feedly = "\ue27b"
	# CHAR : 
	fae_file_export = "\ue27c"
	# CHAR : 
	fae_file_import = "\ue27d"
	# CHAR : 
	fae_fingerprint = "\ue23f"
	# CHAR : 
	fae_floppy = "\ue240"
	# CHAR : 
	fae_footprint = "\ue241"
	# CHAR : 
	fae_freecodecamp = "\ue242"
	# CHAR : 
	fae_galaxy = "\ue243"
	# CHAR : 
	fae_galery = "\ue244"
	# CHAR : 
	fae_gift_card = "\ue2a0"
	# CHAR : 
	fae_glass = "\ue245"
	# CHAR : 
	fae_google_drive = "\ue246"
	# CHAR : 
	fae_google_play = "\ue247"
	# CHAR : 
	fae_gps = "\ue248"
	# CHAR : 
	fae_grav = "\ue249"
	# CHAR : 
	fae_guitar = "\ue24a"
	# CHAR : 
	fae_gut = "\ue24b"
	# CHAR : 
	fae_halter = "\ue24c"
	# CHAR : 
	fae_hamburger = "\ue24d"
	# CHAR : 
	fae_hat = "\ue24e"
	# CHAR : 
	fae_hexagon = "\ue24f"
	# CHAR : 
	fae_high_heel = "\ue250"
	# CHAR : 
	fae_hotdog = "\ue251"
	# CHAR : 
	fae_ice_cream = "\ue252"
	# CHAR : 
	fae_id_card = "\ue253"
	# CHAR : 
	fae_imdb = "\ue254"
	# CHAR : 
	fae_infinity = "\ue255"
	# CHAR : 
	fae_injection = "\ue2a1"
	# CHAR : 
	fae_isle = "\ue2a2"
	# CHAR : 
	fae_java = "\ue256"
	# CHAR : 
	fae_layers = "\ue257"
	# CHAR : 
	fae_lips = "\ue258"
	# CHAR : 
	fae_lipstick = "\ue259"
	# CHAR : 
	fae_liver = "\ue25a"
	# CHAR : 
	fae_lollipop = "\ue2a3"
	# CHAR : 
	fae_loyalty_card = "\ue2a4"
	# CHAR : 
	fae_lung = "\ue25b"
	# CHAR : 
	fae_makeup_brushes = "\ue25c"
	# CHAR : 
	fae_maximize = "\ue25d"
	# CHAR : 
	fae_meat = "\ue2a5"
	# CHAR : 
	fae_medicine = "\ue221"
	# CHAR : 
	fae_microscope = "\ue222"
	# CHAR : 
	fae_milk_bottle = "\ue223"
	# CHAR : 
	fae_minimize = "\ue224"
	# CHAR : 
	fae_molecule = "\ue225"
	# CHAR : 
	fae_moon_cloud = "\ue226"
	# CHAR : 
	fae_mountains = "\ue2a6"
	# CHAR : 
	fae_mushroom = "\ue227"
	# CHAR : 
	fae_mustache = "\ue228"
	# CHAR : 
	fae_mysql = "\ue229"
	# CHAR : 
	fae_nintendo = "\ue22a"
	# CHAR : 
	fae_orange = "\ue2a7"
	# CHAR : 
	fae_palette_color = "\ue22b"
	# CHAR : 
	fae_peach = "\ue2a8"
	# CHAR : 
	fae_pear = "\ue2a9"
	# CHAR : 
	fae_pi = "\ue22c"
	# CHAR : 
	fae_pizza = "\ue22d"
	# CHAR : 
	fae_planet = "\ue22e"
	# CHAR : 
	fae_plant = "\ue22f"
	# CHAR : 
	fae_playstation = "\ue230"
	# CHAR : 
	fae_poison = "\ue231"
	# CHAR : 
	fae_popcorn = "\ue232"
	# CHAR : 
	fae_popsicle = "\ue233"
	# CHAR : 
	fae_pulse = "\ue234"
	# CHAR : 
	fae_python = "\ue235"
	# CHAR : 
	fae_quora_circle = "\ue236"
	# CHAR : 
	fae_quora_square = "\ue237"
	# CHAR : 
	fae_radioactive = "\ue238"
	# CHAR : 
	fae_raining = "\ue239"
	# CHAR : 
	fae_real_heart = "\ue23a"
	# CHAR : 
	fae_refrigerator = "\ue23b"
	# CHAR : 
	fae_restore = "\ue23c"
	# CHAR : 
	fae_ring = "\ue23d"
	# CHAR : 
	fae_ruby = "\ue23e"
	# CHAR : 
	fae_ruby_o = "\ue21e"
	# CHAR : 
	fae_ruler = "\ue21f"
	# CHAR : 
	fae_shirt = "\ue218"
	# CHAR : 
	fae_slash = "\ue216"
	# CHAR : 
	fae_smaller = "\ue200"
	# CHAR : 
	fae_snowing = "\ue201"
	# CHAR : 
	fae_soda = "\ue202"
	# CHAR : 
	fae_sofa = "\ue203"
	# CHAR : 
	fae_soup = "\ue204"
	# CHAR : 
	fae_spermatozoon = "\ue205"
	# CHAR : 
	fae_spin_double = "\ue206"
	# CHAR : 
	fae_stomach = "\ue207"
	# CHAR : 
	fae_storm = "\ue208"
	# CHAR : 
	fae_sun_cloud = "\ue21d"
	# CHAR : 
	fae_sushi = "\ue21a"
	# CHAR : 
	fae_tacos = "\ue219"
	# CHAR : 
	fae_telegram = "\ue217"
	# CHAR : 
	fae_telegram_circle = "\ue215"
	# CHAR : 
	fae_telescope = "\ue209"
	# CHAR : 
	fae_thermometer = "\ue20a"
	# CHAR : 
	fae_thermometer_high = "\ue20b"
	# CHAR : 
	fae_thermometer_low = "\ue20c"
	# CHAR : 
	fae_thin_close = "\ue20d"
	# CHAR : 
	fae_toilet = "\ue20e"
	# CHAR : 
	fae_tools = "\ue20f"
	# CHAR : 
	fae_tooth = "\ue210"
	# CHAR : 
	fae_tree = "\ue21c"
	# CHAR : 
	fae_triangle_ruler = "\ue21b"
	# CHAR : 
	fae_umbrella = "\ue220"
	# CHAR : 
	fae_uterus = "\ue211"
	# CHAR : 
	fae_virus = "\ue214"
	# CHAR : 
	fae_w3c = "\ue212"
	# CHAR : 
	fae_walking = "\ue213"
	# CHAR : 
	fae_wallet = "\ue25e"
	# CHAR : 
	fae_wind = "\ue27e"
	# CHAR : 
	fae_xbox = "\ue29d"


# This File GEN using nerdicons_gen.py

class Extra:

	# CHAR : 
	extra_progress_empty_left = "\uee00"
	# CHAR : 
	extra_progress_empty_mid = "\uee01"
	# CHAR : 
	extra_progress_empty_right = "\uee02"
	# CHAR : 
	extra_progress_full_left = "\uee03"
	# CHAR : 
	extra_progress_full_mid = "\uee04"
	# CHAR : 
	extra_progress_full_right = "\uee05"
	# CHAR : 
	extra_progress_spinner_1 = "\uee06"
	# CHAR : 
	extra_progress_spinner_2 = "\uee07"
	# CHAR : 
	extra_progress_spinner_3 = "\uee08"
	# CHAR : 
	extra_progress_spinner_4 = "\uee09"
	# CHAR : 
	extra_progress_spinner_5 = "\uee0a"
	# CHAR : 
	extra_progress_spinner_6 = "\uee0b"


# This File GEN using nerdicons_gen.py

class Iec:

	# CHAR : ⏻
	iec_power = "\u23fb"
	# CHAR : ⭘
	iec_power_off = "\u2b58"
	# CHAR : ⏽
	iec_power_on = "\u23fd"
	# CHAR : ⏾
	iec_sleep_mode = "\u23fe"
	# CHAR : ⏼
	iec_toggle_power = "\u23fc"


# This File GEN using nerdicons_gen.py

class Linux:

	# CHAR : 
	linux_almalinux = "\uf31d"
	# CHAR : 
	linux_alpine = "\uf300"
	# CHAR : 
	linux_aosc = "\uf301"
	# CHAR : 
	linux_apple = "\uf302"
	# CHAR : 
	linux_archcraft = "\uf345"
	# CHAR : 
	linux_archlabs = "\uf31e"
	# CHAR : 
	linux_archlinux = "\uf303"
	# CHAR : 
	linux_arcolinux = "\uf346"
	# CHAR : 
	linux_arduino = "\uf34b"
	# CHAR : 
	linux_artix = "\uf31f"
	# CHAR : 
	linux_awesome = "\uf354"
	# CHAR : 
	linux_biglinux = "\uf347"
	# CHAR : 
	linux_bspwm = "\uf355"
	# CHAR : 
	linux_budgie = "\uf320"
	# CHAR : 
	linux_centos = "\uf304"
	# CHAR : 
	linux_cinnamon = "\uf35f"
	# CHAR : 
	linux_codeberg = "\uf330"
	# CHAR : 
	linux_coreos = "\uf305"
	# CHAR : 
	linux_crystal = "\uf348"
	# CHAR : 
	linux_debian = "\uf306"
	# CHAR : 
	linux_deepin = "\uf321"
	# CHAR : 
	linux_devuan = "\uf307"
	# CHAR : 
	linux_docker = "\uf308"
	# CHAR : 
	linux_dwm = "\uf356"
	# CHAR : 
	linux_elementary = "\uf309"
	# CHAR : 
	linux_endeavour = "\uf322"
	# CHAR : 
	linux_enlightenment = "\uf357"
	# CHAR : 
	linux_fdroid = "\uf36a"
	# CHAR : 
	linux_fedora = "\uf30a"
	# CHAR : 
	linux_fedora_inverse = "\uf30b"
	# CHAR : 
	linux_ferris = "\uf323"
	# CHAR : 
	linux_flathub = "\uf324"
	# CHAR : 
	linux_fluxbox = "\uf358"
	# CHAR : 
	linux_forgejo = "\uf335"
	# CHAR : 
	linux_fosdem = "\uf36b"
	# CHAR : 
	linux_freebsd = "\uf30c"
	# CHAR : 
	linux_freecad = "\uf336"
	# CHAR : 
	linux_freedesktop = "\uf360"
	# CHAR : 
	linux_garuda = "\uf337"
	# CHAR : 
	linux_gentoo = "\uf30d"
	# CHAR : 
	linux_gimp = "\uf338"
	# CHAR : 
	linux_gitea = "\uf339"
	# CHAR : 
	linux_gnome = "\uf361"
	# CHAR : 
	linux_gnu_guix = "\uf325"
	# CHAR : 
	linux_gtk = "\uf362"
	# CHAR : 
	linux_hyperbola = "\uf33a"
	# CHAR : 
	linux_hyprland = "\uf359"
	# CHAR : 
	linux_i3 = "\uf35a"
	# CHAR : 
	linux_illumos = "\uf326"
	# CHAR : 
	linux_inkscape = "\uf33b"
	# CHAR : 
	linux_jwm = "\uf35b"
	# CHAR : 
	linux_kali_linux = "\uf327"
	# CHAR : 
	linux_kde = "\uf373"
	# CHAR : 
	linux_kde_neon = "\uf331"
	# CHAR : 
	linux_kde_plasma = "\uf332"
	# CHAR : 
	linux_kdenlive = "\uf33c"
	# CHAR : 
	linux_kicad = "\uf34c"
	# CHAR : 
	linux_krita = "\uf33d"
	# CHAR : 
	linux_kubuntu = "\uf333"
	# CHAR : 
	linux_kubuntu_inverse = "\uf334"
	# CHAR : 
	linux_leap = "\uf37e"
	# CHAR : 
	linux_libreoffice = "\uf376"
	# CHAR : 
	linux_libreofficebase = "\uf377"
	# CHAR : 
	linux_libreofficecalc = "\uf378"
	# CHAR : 
	linux_libreofficedraw = "\uf379"
	# CHAR : 
	linux_libreofficeimpress = "\uf37a"
	# CHAR : 
	linux_libreofficemath = "\uf37b"
	# CHAR : 
	linux_libreofficewriter = "\uf37c"
	# CHAR : 
	linux_linuxmint = "\uf30e"
	# CHAR : 
	linux_linuxmint_inverse = "\uf30f"
	# CHAR : 
	linux_locos = "\uf349"
	# CHAR : 
	linux_lxde = "\uf363"
	# CHAR : 
	linux_lxle = "\uf33e"
	# CHAR : 
	linux_lxqt = "\uf364"
	# CHAR : 
	linux_mageia = "\uf310"
	# CHAR : 
	linux_mandriva = "\uf311"
	# CHAR : 
	linux_manjaro = "\uf312"
	# CHAR : 
	linux_mate = "\uf365"
	# CHAR : 
	linux_mpv = "\uf36e"
	# CHAR : 
	linux_mxlinux = "\uf33f"
	# CHAR : 
	linux_neovim = "\uf36f"
	# CHAR : 
	linux_nixos = "\uf313"
	# CHAR : 
	linux_nobara = "\uf380"
	# CHAR : 
	linux_octoprint = "\uf34d"
	# CHAR : 
	linux_openbsd = "\uf328"
	# CHAR : 
	linux_openscad = "\uf34e"
	# CHAR : 
	linux_opensuse = "\uf314"
	# CHAR : 
	linux_osh = "\uf34f"
	# CHAR : 
	linux_oshwa = "\uf350"
	# CHAR : 
	linux_osi = "\uf36c"
	# CHAR : 
	linux_parabola = "\uf340"
	# CHAR : 
	linux_parrot = "\uf329"
	# CHAR : 
	linux_pop_os = "\uf32a"
	# CHAR : 
	linux_postmarketos = "\uf374"
	# CHAR : 
	linux_prusaslicer = "\uf351"
	# CHAR : 
	linux_puppy = "\uf341"
	# CHAR : 
	linux_qt = "\uf375"
	# CHAR : 
	linux_qtile = "\uf35c"
	# CHAR : 
	linux_qubesos = "\uf342"
	# CHAR : 
	linux_raspberry_pi = "\uf315"
	# CHAR : 
	linux_redhat = "\uf316"
	# CHAR : 
	linux_reprap = "\uf352"
	# CHAR : 
	linux_riscv = "\uf353"
	# CHAR : 
	linux_river = "\uf381"
	# CHAR : 
	linux_rocky_linux = "\uf32b"
	# CHAR : 
	linux_sabayon = "\uf317"
	# CHAR : 
	linux_slackware = "\uf318"
	# CHAR : 
	linux_slackware_inverse = "\uf319"
	# CHAR : 
	linux_snappy = "\uf32c"
	# CHAR : 
	linux_solus = "\uf32d"
	# CHAR : 
	linux_sway = "\uf35d"
	# CHAR : 
	linux_tails = "\uf343"
	# CHAR : 
	linux_thunderbird = "\uf370"
	# CHAR : 
	linux_tor = "\uf371"
	# CHAR : 
	linux_trisquel = "\uf344"
	# CHAR : 
	linux_tumbleweed = "\uf37d"
	# CHAR : 
	linux_tux = "\uf31a"
	# CHAR : 
	linux_typst = "\uf37f"
	# CHAR : 
	linux_ubuntu = "\uf31b"
	# CHAR : 
	linux_ubuntu_inverse = "\uf31c"
	# CHAR : 
	linux_vanilla = "\uf366"
	# CHAR : 
	linux_void = "\uf32e"
	# CHAR : 
	linux_vscodium = "\uf372"
	# CHAR : 
	linux_wayland = "\uf367"
	# CHAR : 
	linux_wikimedia = "\uf36d"
	# CHAR : 
	linux_xerolinux = "\uf34a"
	# CHAR : 
	linux_xfce = "\uf368"
	# CHAR : 
	linux_xmonad = "\uf35e"
	# CHAR : 
	linux_xorg = "\uf369"
	# CHAR : 
	linux_zorin = "\uf32f"